@@ -66,8 +66,8 @@ extern "C" {
 #define KNH_ASSERT_cid(cid)    KNH_ASSERT(cid < KNH_TCLASS_SIZE)
 #define CLASSN(cid)   knh_ClassTable_CLASSN(ctx, cid)
 #define CLASSNo(o)    knh_ClassTable_CLASSN(ctx, knh_Object_cid(o))
-#define KNH_DEF(ctx, cid)  konoha_geClassTableDefaultValue(ctx, cid)
-#define KNH_DEF(ctx, cid)  konoha_geClassTableDefaultValue(ctx, cid)
+#define KNH_DEF(ctx, cid)  konoha_getClassDefaultValue(ctx, cid)
+#define KNH_DEF(ctx, cid)  konoha_getClassDefaultValue(ctx, cid)
 #define TYPEN(type)  knh_TYPEN(ctx,type)
 #define KNH_STDIN          (((Context*)ctx)->in)
 #define KNH_STDOUT         (((Context*)ctx)->out)
