@@ -108,12 +108,12 @@ void knh_BytesConv__k(Ctx *ctx, BytesConv *o, OutputStream *w, String *m);
 /* ../src/class/knh_Class.c */
 knh_struct_t knh_StructTable_newId(Ctx *ctx);
 knh_class_t knh_ClassTable_newId(Ctx *ctx);
-void konoha_seClassTableName(Ctx *ctx, knh_class_t cid, String *lname);
+void konoha_setClassName(Ctx *ctx, knh_class_t cid, String *lname);
 char *knh_ClassTable_CLASSN(Ctx *ctx, knh_class_t cid);
-void konoha_seClassTableDefaultValue(Ctx *ctx, knh_class_t cid, Object *value, knh_fdefault fdefault);
-Object *konoha_geClassTableDefaultValue(Ctx *ctx, knh_class_t cid);
+void konoha_setClassDefaultValue(Ctx *ctx, knh_class_t cid, Object *value, knh_fdefault fdefault);
+Object *konoha_getClassDefaultValue(Ctx *ctx, knh_class_t cid);
 Object *konoha_getDefaultValue(Ctx *ctx, knh_type_t type);
-void konoha_seClassTableParam(Ctx *ctx, knh_class_t cid, knh_class_t p1, knh_class_t p2);
+void konoha_setClassParam(Ctx *ctx, knh_class_t cid, knh_class_t p1, knh_class_t p2);
 knh_class_t konoha_addGenericsClass(Ctx *ctx, knh_class_t cid, String *name, knh_class_t bcid, knh_class_t p1, knh_class_t p2);
 ClassStruct* new_ClassStruct0(Ctx *ctx, int field_size, int method_size);
 knh_index_t knh_Class_indexOfField(Ctx *ctx, knh_class_t cid, knh_fieldn_t fn);
@@ -129,9 +129,6 @@ void knh_ClassMap_sort(Ctx *ctx, ClassMap *o);
 void knh_ClassMap_add(Ctx *ctx, ClassMap *o, Mapper *map);
 void knh_ClassMap__dump(Ctx *ctx, ClassMap *o, OutputStream *w, String *m);
 void knh_ClassMap__man(Ctx *ctx, ClassMap *o, OutputStream *w, knh_class_t cid);
-int konoha_addClassConst(Ctx *ctx, knh_class_t cid, String* name, Object *value);
-int konoha_existsClassConst(Ctx *ctx, knh_class_t cid, knh_bytes_t name);
-Object *konoha_getClassConst(Ctx *ctx, knh_class_t cid, knh_bytes_t name);
 /* ../src/class/knh_Class_type_t.c */
 knh_class_t knh_pmztype_toclass(Ctx *ctx, knh_type_t t, knh_class_t this_cid);
 knh_type_t knh_pmztype_totype(Ctx *ctx, knh_type_t t, knh_class_t this_cid);
@@ -299,21 +296,24 @@ Method* knh_Class_getMethod__(Ctx *ctx, knh_class_t this_cid, knh_methodn_t mn,
 Method *konoha_lookupMethod(Ctx *ctx, knh_class_t cid, knh_methodn_t mn);
 Method *konoha_lookupFormatter(Ctx *ctx, knh_class_t cid, knh_methodn_t mn);
 /* ../src/class/knh_NameSpace.c */
-NameSpace* new_NameSpace(Ctx *ctx, NameSpace *parent, String *nsname);
-void knh_NameSpace_seClassTable(Ctx *ctx, NameSpace *o, String *name, knh_class_t c);
-knh_class_t knh_NameSpace_geClassTable(Ctx *ctx, NameSpace *o, knh_bytes_t name);
+NameSpace* new_NameSpace(Ctx *ctx, String *nsname);
+void knh_NameSpace_importNameSpace(Ctx *ctx, NameSpace *ns, NameSpace *other);
+Script *knh_NameSpace_getScript(Ctx *ctx, NameSpace *ns);
+knh_class_t konoha_getcid(Ctx *ctx, knh_bytes_t lname);
+knh_class_t konoha_findcid(Ctx *ctx, knh_bytes_t lname);
+void knh_NameSpace_setcid(Ctx *ctx, NameSpace *o, String *name, knh_class_t c);
 void knh_NameSpace_setLocalName(Ctx *ctx, NameSpace *o, knh_class_t cid);
+knh_class_t knh_NameSpace_getcid(Ctx *ctx, NameSpace *o, knh_bytes_t name);
 char* knh_Context_CLASSN(Ctx *ctx, knh_class_t cid);
-void knh_NameSpace_import(Ctx *ctx, NameSpace *o, knh_bytes_t p);
-knh_type_t knh_NameSpace_getType(Ctx *ctx, NameSpace *o, knh_bytes_t name);
+void knh_NameSpace_importClass(Ctx *ctx, NameSpace *o, knh_bytes_t pkgname);
+knh_type_t knh_NameSpace_gettype(Ctx *ctx, NameSpace *ns, knh_bytes_t name, int isNullable);
+Object * knh_NameSpace_getConstNULL(Ctx *ctx, NameSpace *ns, knh_bytes_t name);
+void knh_NameSpace_addConst(Ctx *ctx, NameSpace *ns, String *name, Object *value);
+void knh_NameSpace_setFuncClass(Ctx *ctx, NameSpace *o, knh_methodn_t mn, knh_class_t c);
+knh_class_t knh_NameSpace_getFuncClass(Ctx *ctx, NameSpace *o, knh_bytes_t funcname);
 knh_class_t knh_tclass_classURN(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn);
 knh_class_t knh_tclass_loadURN(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn);
 knh_type_t knh_NameSpace_tagcid(Ctx *ctx, NameSpace *o, knh_class_t bcid, knh_bytes_t tag);
-void knh_NameSpace_setFuncClass(Ctx *ctx, NameSpace *o, knh_methodn_t mn, knh_class_t c);
-knh_class_t knh_NameSpace_getFuncClass(Ctx *ctx, NameSpace *o, knh_bytes_t funcname);
-knh_bool_t knh_NameSpace_existsConst(Ctx *ctx, NameSpace *o, knh_bytes_t name);
-void knh_NameSpace_addConst(Ctx *ctx, NameSpace *o, String *name, Object *value);
-Object* knh_NameSpace_getConst(Ctx *ctx, NameSpace *o, knh_bytes_t name);
 /* ../src/class/knh_Number.c */
 knh_int_t knh_Number_tointeger(Any *o);
 knh_float_t knh_Number_tofloat(Any *o);
@@ -368,7 +368,7 @@ ResultSet* new_ResultSet(Ctx *ctx);
 knh_boolean_t knh_ResultSet_next(Ctx *ctx, ResultSet *o);
 METHOD knh__ResultSet_next(Ctx *ctx, knh_sfp_t *sfp);
 void knh_ResultSet_close(Ctx *ctx, ResultSet *o);
-void knh_ResultSet_initTargeClassTable(ResultSet *o, knh_class_t tcid);
+void knh_ResultSet_initTargetClass(ResultSet *o, knh_class_t tcid);
 String *knh_ResultSet_getName(Ctx *ctx, ResultSet *o, size_t n);
 int knh_ResultSet_findColumn(Ctx *ctx, ResultSet *o, knh_bytes_t name);
 knh_type_t knh_ResultSet_get_type(Ctx *ctx, ResultSet *o, size_t n);
@@ -376,7 +376,7 @@ knh_int_t knh_ResultSet_getInt(Ctx *ctx, ResultSet *o, size_t n);
 knh_float_t knh_ResultSet_getFloat(Ctx *ctx, ResultSet *o, size_t n);
 String* knh_ResultSet_getString(Ctx *ctx, ResultSet *o, size_t n);
 /* ../src/class/knh_Script.c */
-Script *knh_NameSpace_getScript(Ctx *ctx, NameSpace *ns);
+Script *new_Script(Ctx *ctx, knh_bytes_t nsname);
 void knh_Script__k(Ctx *ctx, Script *o, OutputStream *w, String *m);
 void knh_Script__dump(Ctx *ctx, Script *o, OutputStream *w, String *m);
 /* ../src/class/knh_String.c */
@@ -519,6 +519,7 @@ Term * knh_StmtDECL_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns);
 Term *knh_StmtLET_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_type_t reqt);
 Term *knh_StmtEXPR_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_class_t reqt);
 void knh_Stmt_toBLOCK(Ctx *ctx, Stmt *stmt, size_t n);
+void knh_Asm_initReg(Ctx *ctx, Asm *abr);
 int knh_Stmt_initParams(Ctx *ctx, Stmt *pstmt, Asm *abr, NameSpace *ns, int level);
 Term * knh_StmtMETHOD_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns);
 Term *knh_StmtFORMAT_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns);
@@ -592,8 +593,6 @@ void *konoha_generateCallBackFunc(Ctx *ctx, void *func, Closure *c);
 void KNH_ACLASS(Ctx *ctx, knh_class_t cid, knh_class_t p1);
 void KNH_ICLASS(Ctx *ctx, knh_class_t cid, knh_class_t p1);
 knh_class_t KNH_XCLASS(Ctx *ctx, knh_class_t cid, knh_class_t bcid, ClassSpec *cs);
-knh_class_t konoha_getcid(Ctx *ctx, char *lname);
-knh_class_t konoha_findcid(Ctx *ctx, knh_bytes_t lname);
 /* ../src/main/konoha_api.c */
 void konoha_init(void);
 int knh_readline_askYesNo(char *prompt, int def);
@@ -644,9 +643,8 @@ int knh_sfp_argc(Ctx *ctx, knh_sfp_t *v);
 METHOD knh__System_stackdump(Ctx *ctx, knh_sfp_t *sfp);
 char * knh_format_mtdparam(Ctx *ctx, char *buf, size_t bufsiz, Method *mtd, int n); void knh_sfp_typecheck(Ctx *ctx, knh_sfp_t *sfp, Method *mtd, knh_code_t *pc);
 /* ../src/main/system.c */
-int konoha_existsConst(Ctx *ctx, knh_bytes_t name);
-Object *konoha_getConst(Ctx *ctx, knh_bytes_t name);
-void konoha_addConst(Ctx *ctx, String *name, Object *value);
+int konoha_addClassConst(Ctx *ctx, knh_class_t cid, String* name, Object *value);
+Object *konoha_getClassConstNULL(Ctx *ctx, knh_class_t cid, knh_bytes_t name);
 void knh_Const__man(Ctx *ctx, knh_class_t cid, OutputStream *w);
 Object *konoha_getSystemConst(Ctx *ctx, int n);
 int knh_bytes_isOptionalMT(knh_bytes_t t);
@@ -664,7 +662,7 @@ void konoha_addDriverAPI(Ctx *ctx, char *alias, knh_drvapi_t* p);
 knh_drvapi_t *konoha_getDriverAPI(Ctx *ctx, int type, knh_bytes_t name);
 NameSpace *knh_System_loadPackage(Ctx *ctx, knh_bytes_t pkgname);
 NameSpace *knh_System_getNameSpace(Ctx *ctx, knh_bytes_t name);
-ClassSpec *konoha_geClassTableSpec(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn);
+ClassSpec *konoha_getClassSpec(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn);
 /* ../src/main/systemtable.c */
 void knh_Context_traverse(Ctx *ctx, knh_Context_t *o, knh_ftraverse ftr);
 void konoha_traverse(Ctx* ctx, knh_ftraverse ftr);
