@@ -703,6 +703,7 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"callcc", FIELDN_callcc},
 	{"ch", FIELDN_ch},
 	{"changeChannel", FIELDN_changeChannel},
+	{"class", FIELDN_class},
 	{"clear", FIELDN_clear},
 	{"close", FIELDN_close},
 	{"concat", FIELDN_concat},
@@ -737,7 +738,6 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"g", FIELDN_g},
 	{"gCMarked", FIELDN_gCMarked},
 	{"gc", FIELDN_gc},
-	{"geClassTable", FIELDN_geClassTable},
 	{"h", FIELDN_h},
 	{"hasDir", FIELDN_hasDir},
 	{"hasFile", FIELDN_hasFile},
@@ -846,7 +846,6 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"opOffset", FIELDN_opOffset},
 	{"opPrev", FIELDN_opPrev},
 	{"opRshift", FIELDN_opRshift},
-	{"opSize", FIELDN_opSize},
 	{"opSub", FIELDN_opSub},
 	{"opSubset", FIELDN_opSubset},
 	{"opSubsete", FIELDN_opSubsete},
@@ -868,6 +867,7 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"random", FIELDN_random},
 	{"re", FIELDN_re},
 	{"readLine", FIELDN_readLine},
+	{"register", FIELDN_register},
 	{"release", FIELDN_release},
 	{"remove", FIELDN_remove},
 	{"replace", FIELDN_replace},
@@ -1036,9 +1036,9 @@ static knh_MethodData_t MethodData[] = {
 	{knh__IArray_opLshift, KNH_FLAG_MF_VARARGS, CLASS_IArray, METHODN_opLshift, 0, MFN_void_nInt_, (void*)NULL},
 	{knh__FArray_add, 0, CLASS_FArray, METHODN_add, 0, MFN_void_nFloat, (void*)NULL},
 	{knh__FArray_opLshift, KNH_FLAG_MF_VARARGS, CLASS_FArray, METHODN_opLshift, 0, MFN_void_nFloat_, (void*)NULL},
-	{knh__Array_opSize, 0, CLASS_Array, METHODN_opSize, 0, MFN_nInt, (void*)NULL},
-	{knh__Array_opSize, 0, CLASS_IArray, METHODN_opSize, 0, MFN_nInt, (void*)NULL},
-	{knh__Array_opSize, 0, CLASS_FArray, METHODN_opSize, 0, MFN_nInt, (void*)NULL},
+	{knh__Array_getSize, 0, CLASS_Array, METHODN_getSize, 0, MFN_nInt, (void*)NULL},
+	{knh__Array_getSize, 0, CLASS_IArray, METHODN_getSize, 0, MFN_nInt, (void*)NULL},
+	{knh__Array_getSize, 0, CLASS_FArray, METHODN_getSize, 0, MFN_nInt, (void*)NULL},
 	{knh__Array_get, 0, CLASS_Array, METHODN_get, 0, MFN_nAny1_nInt, (void*)NULL},
 	{knh__IArray_get, 0, CLASS_IArray, METHODN_get, 0, MFN_nInt_nInt, (void*)NULL},
 	{knh__FArray_get, 0, CLASS_FArray, METHODN_get, 0, MFN_nFloat_nInt, (void*)NULL},
@@ -1093,7 +1093,7 @@ static knh_MethodData_t MethodData[] = {
 	{knh__Bytes_putc, 0, CLASS_Bytes, METHODN_putc, 0, MFN_void_nInt, (void*)NULL},
 	{knh__Bytes_write, 0, CLASS_Bytes, METHODN_write, 0, MFN_void_nBytes_Int_Int, (void*)NULL},
 	{knh__Bytes_opLshift, KNH_FLAG_MF_VARARGS, CLASS_Bytes, METHODN_opLshift, 0, MFN_void_nInt_, (void*)NULL},
-	{knh__Bytes_opSize, 0, CLASS_Bytes, METHODN_opSize, 0, MFN_nInt, (void*)NULL},
+	{knh__Bytes_getSize, 0, CLASS_Bytes, METHODN_getSize, 0, MFN_nInt, (void*)NULL},
 	{knh__Bytes_get, 0, CLASS_Bytes, METHODN_get, 0, MFN_nInt_nInt, (void*)NULL},
 	{knh__Bytes_set, 0, CLASS_Bytes, METHODN_set, 0, MFN_void_nInt_nInt, (void*)NULL},
 	{knh__Bytes_opFill, 0, CLASS_Bytes, METHODN_opFill, 0, MFN_void_nInt, (void*)NULL},
@@ -1101,7 +1101,7 @@ static knh_MethodData_t MethodData[] = {
 	{knh__Connection_new, 0, CLASS_Connection, METHODN_new, 0, MFN_nConnection_nString, (void*)NULL},
 	{knh__Connection_query, 0, CLASS_Connection, METHODN_query, 0, MFN_nResultSet_nString, (void*)NULL},
 	{knh__Connection_exec, 0, CLASS_Connection, METHODN_exec, 0, MFN_void_nString, (void*)NULL},
-	{knh__ResultSet_opSize, 0, CLASS_ResultSet, METHODN_opSize, 0, MFN_nInt_nAny, (void*)NULL},
+	{knh__ResultSet_getSize, 0, CLASS_ResultSet, METHODN_getSize, 0, MFN_nInt_nAny, (void*)NULL},
 	{knh__ResultSet_getName, 0, CLASS_ResultSet, METHODN_getName, 0, MFN_nString_nInt, (void*)NULL},
 	{knh__ResultSet_getInt, 0, CLASS_ResultSet, METHODN_getInt, 0, MFN_Int_nAny, (void*)NULL},
 	{knh__ResultSet_getFloat, 0, CLASS_ResultSet, METHODN_getFloat, 0, MFN_Float_nAny, (void*)NULL},
@@ -1115,7 +1115,7 @@ static knh_MethodData_t MethodData[] = {
 	{knh__DictMap_set, 0, CLASS_DictMap, METHODN_set, 0, MFN_void_nString_Any1, (void*)NULL},
 	{knh__DictMap_remove, 0, CLASS_DictMap, METHODN_remove, 0, MFN_void_nString, (void*)NULL},
 	{knh__DictMap_clear, 0, CLASS_DictMap, METHODN_clear, 0, MFN_void, (void*)NULL},
-	{knh__DictMap_opSize, 0, CLASS_DictMap, METHODN_opSize, 0, MFN_nInt, (void*)NULL},
+	{knh__DictMap_getSize, 0, CLASS_DictMap, METHODN_getSize, 0, MFN_nInt, (void*)NULL},
 	{knh__DictMap_opLshift, KNH_FLAG_MF_VARARGS, CLASS_DictMap, METHODN_opLshift, 0, MFN_void_Any_, (void*)NULL},
 	{knh__DictMap_opItr, 0, CLASS_DictMap, METHODN_opItr, 0, MFN_iString, (void*)NULL},
 	{knh_fmethod_movableText, 0, CLASS_DictMap, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_DictMap__k},
@@ -1126,7 +1126,7 @@ static knh_MethodData_t MethodData[] = {
 	{knh__DictSet_set, 0, CLASS_DictSet, METHODN_set, 0, MFN_void_nString_nInt, (void*)NULL},
 	{knh__DictSet_remove, 0, CLASS_DictSet, METHODN_remove, 0, MFN_void_nString, (void*)NULL},
 	{knh__DictSet_clear, 0, CLASS_DictSet, METHODN_clear, 0, MFN_void, (void*)NULL},
-	{knh__DictSet_opSize, 0, CLASS_DictSet, METHODN_opSize, 0, MFN_nInt, (void*)NULL},
+	{knh__DictSet_getSize, 0, CLASS_DictSet, METHODN_getSize, 0, MFN_nInt, (void*)NULL},
 	{knh__DictSet_opLshift, KNH_FLAG_MF_VARARGS, CLASS_DictSet, METHODN_opLshift, 0, MFN_void_String_, (void*)NULL},
 	{knh__DictSet_opItr, 0, CLASS_DictSet, METHODN_opItr, 0, MFN_iString, (void*)NULL},
 	{knh_fmethod_movableText, 0, CLASS_DictSet, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_DictSet__k},
@@ -1160,7 +1160,7 @@ static knh_MethodData_t MethodData[] = {
 	{knh__Int_opRshift, KNH_FLAG_MF_CONST, CLASS_Int, METHODN_opRshift, 0, MFN_nInt_nInt, (void*)NULL},
 	{knh__Int_opNext, KNH_FLAG_MF_CONST, CLASS_Int, METHODN_opNext, 0, MFN_nInt, (void*)NULL},
 	{knh__Int_opPrev, KNH_FLAG_MF_CONST, CLASS_Int, METHODN_opPrev, 0, MFN_nInt, (void*)NULL},
-	{knh__Int_opSize, KNH_FLAG_MF_NULLBASE|KNH_FLAG_MF_CONST, CLASS_Int, METHODN_opSize, 0, MFN_nInt, (void*)NULL},
+	{knh__Int_getSize, KNH_FLAG_MF_NULLBASE|KNH_FLAG_MF_CONST, CLASS_Int, METHODN_getSize, 0, MFN_nInt, (void*)NULL},
 	{knh__Int_random, KNH_FLAG_MF_STATIC, CLASS_Int, METHODN_random, 0, MFN_nInt_Int, (void*)NULL},
 	{knh__Float_opAdd, KNH_FLAG_MF_CONST, CLASS_Float, METHODN_opAdd, 0, MFN_nFloat_nFloat, (void*)NULL},
 	{knh__Float_opNeg, KNH_FLAG_MF_CONST, CLASS_Float, METHODN_opNeg, 0, MFN_nFloat, (void*)NULL},
@@ -1176,7 +1176,7 @@ static knh_MethodData_t MethodData[] = {
 	{knh__Float_opNext, KNH_FLAG_MF_CONST, CLASS_Float, METHODN_opNext, 0, MFN_nFloat, (void*)NULL},
 	{knh__Float_opPrev, KNH_FLAG_MF_CONST, CLASS_Float, METHODN_opPrev, 0, MFN_nFloat, (void*)NULL},
 	{knh__Float_random, KNH_FLAG_MF_STATIC, CLASS_Float, METHODN_random, 0, MFN_nFloat, (void*)NULL},
-	{knh__Float_opSize, KNH_FLAG_MF_NULLBASE|KNH_FLAG_MF_CONST, CLASS_Float, METHODN_opSize, 0, MFN_nInt, (void*)NULL},
+	{knh__Float_getSize, KNH_FLAG_MF_NULLBASE|KNH_FLAG_MF_CONST, CLASS_Float, METHODN_getSize, 0, MFN_nInt, (void*)NULL},
 	{knh__Boolean__s, 0, CLASS_Boolean, METHODN__s, 0, MFN_void_OutputStream_Any, (void*)NULL},
 	{knh__Boolean__k, 0, CLASS_Boolean, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)NULL},
 	{knh__Int__s, 0, CLASS_Int, METHODN__s, 0, MFN_void_OutputStream_Any, (void*)NULL},
@@ -1201,7 +1201,7 @@ static knh_MethodData_t MethodData[] = {
 	{knh__Object_opIs, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_opIs, 0, MFN_nBoolean_Any, (void*)NULL},
 	{knh__Object_opIsa, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_opIsa, 0, MFN_nBoolean_nClass, (void*)NULL},
 	{knh__Object_opTo, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_opTo, 0, MFN_nBoolean_nClass, (void*)NULL},
-	{knh__Object_geClassTable, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_geClassTable, 0, MFN_nClass, (void*)NULL},
+	{knh__Object_getClass, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_getClass, 0, MFN_nClass, (void*)NULL},
 	{knh__Object_isNull, KNH_FLAG_MF_CONST|KNH_FLAG_MF_NULLBASE, CLASS_Object, METHODN_isNull, 0, MFN_nBoolean, (void*)NULL},
 	{knh__Object_isNotNull, KNH_FLAG_MF_CONST|KNH_FLAG_MF_NULLBASE, CLASS_Object, METHODN_isNotNull, 0, MFN_nBoolean, (void*)NULL},
 	{knh__Object_opItr, 0, CLASS_Object, METHODN_opItr, 0, MFN_iThis, (void*)NULL},
@@ -1236,7 +1236,7 @@ static knh_MethodData_t MethodData[] = {
 	{knh__String_startsWith, KNH_FLAG_MF_CONST, CLASS_String, METHODN_startsWith, 0, MFN_nBoolean_nString, (void*)NULL},
 	{knh__String_endsWith, KNH_FLAG_MF_CONST, CLASS_String, METHODN_endsWith, 0, MFN_nBoolean_nString, (void*)NULL},
 	{knh__String_indexOf, KNH_FLAG_MF_CONST, CLASS_String, METHODN_indexOf, 0, MFN_nInt_nString, (void*)NULL},
-	{knh__String_opSize, KNH_FLAG_MF_CONST|KNH_FLAG_MF_NULLBASE, CLASS_String, METHODN_opSize, 0, MFN_nInt, (void*)NULL},
+	{knh__String_getSize, KNH_FLAG_MF_CONST|KNH_FLAG_MF_NULLBASE, CLASS_String, METHODN_getSize, 0, MFN_nInt, (void*)NULL},
 	{knh__String_opAdd, KNH_FLAG_MF_CONST|KNH_FLAG_MF_NULLBASE, CLASS_String, METHODN_opAdd, 0, MFN_nString_Any, (void*)NULL},
 	{knh__String_concat, KNH_FLAG_MF_VARARGS|KNH_FLAG_MF_STATIC|KNH_FLAG_MF_NULLBASE, CLASS_String, METHODN_concat, 0, MFN_nString_Any_, (void*)NULL},
 	{knh__String_opSub, KNH_FLAG_MF_CONST, CLASS_String, METHODN_opSub, 0, MFN_nString_nString, (void*)NULL},
