@@ -136,7 +136,7 @@ knh_class_t knh_class_Array(Ctx *ctx, knh_class_t p1)
 	char buf[CLASSNAME_BUFSIZ];
 	if(p1 == CLASS_Any) return CLASS_Array;
 	knh_snprintf(buf, sizeof(buf), "%s[]", CLASSN(p1));
-	knh_class_t cid = knh_NameSpace_geClassTable(ctx, knh_rootNameSpace, B(buf));
+	knh_class_t cid = konoha_getcid(ctx, B(buf));
 	if(cid == CLASS_unknown) {
 		//DBG2_P("Generating %s", buf);
 		return konoha_addGenericsClass(ctx, CLASS_newid, new_String(ctx, B(buf), NULL), CLASS_Array, p1, CLASS_Nue);
@@ -151,7 +151,7 @@ knh_class_t knh_class_Iterator(Ctx *ctx, knh_class_t p1)
 	char buf[CLASSNAME_BUFSIZ];
 	if(p1 == CLASS_Any) return CLASS_Iterator;
 	knh_snprintf(buf, sizeof(buf), "%s..", CLASSN(p1));
-	knh_class_t cid = knh_NameSpace_geClassTable(ctx, knh_rootNameSpace, B(buf));
+	knh_class_t cid = konoha_getcid(ctx, B(buf));
 	if(cid == CLASS_unknown) {
 		//DBG2_P("*** Generating %s ***", buf);
 		return konoha_addGenericsClass(ctx, CLASS_newid, new_String(ctx, B(buf), NULL), CLASS_Iterator, p1, CLASS_Nue);
@@ -176,7 +176,7 @@ knh_class_t knh_class_Generics(Ctx *ctx, knh_class_t bcid, knh_class_t p1, knh_c
 	else {
 		char buf[CLASSNAME_BUFSIZ];
 		knh_snprintf(buf, sizeof(buf), "%s<%s,%s>", CLASSN(bcid), CLASSN(p1), CLASSN(p2));
-		knh_class_t cid = knh_NameSpace_geClassTable(ctx, knh_rootNameSpace, B(buf));
+		knh_class_t cid = konoha_getcid(ctx, B(buf));
 		if(cid == CLASS_unknown) {
 			//DBG2_P("Generating %s", buf);
 			return konoha_addGenericsClass(ctx, CLASS_newid, new_String(ctx, B(buf), NULL), bcid, p1, p2);
@@ -193,6 +193,10 @@ char* knh_format_type(Ctx *ctx, char *buf, size_t bufsiz, knh_type_t type)
 		knh_snprintf(buf, bufsiz, "void");
 		return buf;
 	}
+	if(type == TYPE_void) {
+		knh_snprintf(buf, bufsiz, "var");
+		return buf;
+	}
 	knh_class_t cid = CLASS_type(type);
 	if(!(cid < ctx->share->ClassTableSize)) {
 		cid = CLASS_Any;
@@ -209,7 +213,7 @@ char* knh_format_type(Ctx *ctx, char *buf, size_t bufsiz, knh_type_t type)
 		knh_snprintf(buf, bufsiz, "%s!", cname);
 		return buf;
 	}
-	knh_snprintf(buf, bufsiz, "%s", cname);
+	knh_snprintf(buf, bufsiz, "%s?", cname);
 	return buf;
 }
 
@@ -221,7 +225,7 @@ char *TYPEQ(knh_type_t type)
 	if(IS_NNTYPE(type)) {
 		return "!";
 	}
-	return "";
+	return "?";
 }
 
 /* ------------------------------------------------------------------------ */
@@ -231,6 +235,7 @@ char *TYPEQ(knh_type_t type)
 char *knh_TYPEN(Ctx *ctx, knh_type_t type)
 {
 	if(type == TYPE_void) return "void";
+	if(type == TYPE_var)  return "var";
 	knh_class_t cid = CLASS_type(type);
 	return CLASSN(cid);
 }
