@@ -38,20 +38,20 @@ extern "C" {
 /* ======================================================================== */
 /* [default_func] */
 
-static knh_bool_t knh_fenumchk__nop(IntUnit *b, knh_integer_t v);
-static int knh_fenumcmp__unsigned(IntUnit *b, knh_integer_t v1, knh_integer_t v2);
-static void knh_fenumfmt__unsigned(IntUnit *b, char *buf, size_t bufsiz, knh_integer_t v);
-static knh_bool_t knh_fenumchk__signed_min(IntUnit *b, knh_integer_t v);
-static knh_bool_t knh_fenumchk__signed_max(IntUnit *b, knh_integer_t v);
-static knh_bool_t knh_fenumchk__signed(IntUnit *b, knh_integer_t v);
-static knh_bool_t knh_fenumchk__unsigned_min(IntUnit *b, knh_integer_t v);
-static knh_bool_t knh_fenumchk__unsigned_max(IntUnit *b, knh_integer_t v);
-static knh_bool_t knh_fenumchk__unsigned(IntUnit *b, knh_integer_t v);
+static knh_bool_t knh_fenumchk__nop(IntUnit *b, knh_int_t v);
+static int knh_fenumcmp__unsigned(IntUnit *b, knh_int_t v1, knh_int_t v2);
+static void knh_fenumfmt__unsigned(IntUnit *b, char *buf, size_t bufsiz, knh_int_t v);
+static knh_bool_t knh_fenumchk__signed_min(IntUnit *b, knh_int_t v);
+static knh_bool_t knh_fenumchk__signed_max(IntUnit *b, knh_int_t v);
+static knh_bool_t knh_fenumchk__signed(IntUnit *b, knh_int_t v);
+static knh_bool_t knh_fenumchk__unsigned_min(IntUnit *b, knh_int_t v);
+static knh_bool_t knh_fenumchk__unsigned_max(IntUnit *b, knh_int_t v);
+static knh_bool_t knh_fenumchk__unsigned(IntUnit *b, knh_int_t v);
 
 /* ------------------------------------------------------------------------ */
 
 static
-knh_bool_t knh_fenumchk__nop(IntUnit *b, knh_integer_t v)
+knh_bool_t knh_fenumchk__nop(IntUnit *b, knh_int_t v)
 {
 	return 1;
 }
@@ -59,25 +59,25 @@ knh_bool_t knh_fenumchk__nop(IntUnit *b, knh_integer_t v)
 /* ------------------------------------------------------------------------ */
 
 static
-int knh_fenumcmp__unsigned(IntUnit *b, knh_integer_t v1, knh_integer_t v2)
+int knh_fenumcmp__unsigned(IntUnit *b, knh_int_t v1, knh_int_t v2)
 {
 	if(v1 == v2) return 0;
-	return ((knh_uint_t)v1) > ((knh_uint_t)v2) ? 1 : 0;
+	return ((knh_uintptr_t)v1) > ((knh_uintptr_t)v2) ? 1 : 0;
 }
 
 /* ------------------------------------------------------------------------ */
 
 static
-void knh_fenumfmt__unsigned(IntUnit *b, char *buf, size_t bufsiz, knh_integer_t v)
+void knh_fenumfmt__unsigned(IntUnit *b, char *buf, size_t bufsiz, knh_int_t v)
 {
-	knh_snprintf(buf, bufsiz, KNH_UINTEGER_FMT, (knh_uinteger_t)v);
+	knh_snprintf(buf, bufsiz, KNH_UINT_FMT, (knh_uint_t)v);
 }
 
 /* ======================================================================== */
 /* [range] */
 
 static
-knh_bool_t knh_fenumchk__signed_min(IntUnit *b, knh_integer_t v)
+knh_bool_t knh_fenumchk__signed_min(IntUnit *b, knh_int_t v)
 {
 	return (DP(b)->min <= v);
 }
@@ -85,7 +85,7 @@ knh_bool_t knh_fenumchk__signed_min(IntUnit *b, knh_integer_t v)
 /* ------------------------------------------------------------------------ */
 
 static
-knh_bool_t knh_fenumchk__signed_max(IntUnit *b, knh_integer_t v)
+knh_bool_t knh_fenumchk__signed_max(IntUnit *b, knh_int_t v)
 {
 	return (v <= DP(b)->max);
 }
@@ -93,7 +93,7 @@ knh_bool_t knh_fenumchk__signed_max(IntUnit *b, knh_integer_t v)
 /* ------------------------------------------------------------------------ */
 
 static
-knh_bool_t knh_fenumchk__signed(IntUnit *b, knh_integer_t v)
+knh_bool_t knh_fenumchk__signed(IntUnit *b, knh_int_t v)
 {
 	return (DP(b)->min <= v && v <= DP(b)->max);
 }
@@ -101,25 +101,25 @@ knh_bool_t knh_fenumchk__signed(IntUnit *b, knh_integer_t v)
 /* ------------------------------------------------------------------------ */
 
 static
-knh_bool_t knh_fenumchk__unsigned_min(IntUnit *b, knh_integer_t v)
+knh_bool_t knh_fenumchk__unsigned_min(IntUnit *b, knh_int_t v)
 {
-	return ((knh_uinteger_t)DP(b)->min) <= ((knh_uinteger_t)v);
+	return ((knh_uint_t)DP(b)->min) <= ((knh_uint_t)v);
 }
 
 /* ------------------------------------------------------------------------ */
 
 static
-knh_bool_t knh_fenumchk__unsigned_max(IntUnit *b, knh_integer_t v)
+knh_bool_t knh_fenumchk__unsigned_max(IntUnit *b, knh_int_t v)
 {
-	return ((knh_uinteger_t)v) <= ((knh_uinteger_t)DP(b)->max);
+	return ((knh_uint_t)v) <= ((knh_uint_t)DP(b)->max);
 }
 
 /* ------------------------------------------------------------------------ */
 
 static
-knh_bool_t knh_fenumchk__unsigned(IntUnit *b, knh_integer_t v)
+knh_bool_t knh_fenumchk__unsigned(IntUnit *b, knh_int_t v)
 {
-	return (((knh_uinteger_t)DP(b)->min) <= ((knh_uinteger_t)v) && ((knh_uinteger_t)v) <= ((knh_uinteger_t)DP(b)->max));
+	return (((knh_uint_t)DP(b)->min) <= ((knh_uint_t)v) && ((knh_uint_t)v) <= ((knh_uint_t)DP(b)->max));
 }
 
 /* ======================================================================== */
@@ -127,7 +127,7 @@ knh_bool_t knh_fenumchk__unsigned(IntUnit *b, knh_integer_t v)
 
 /* ------------------------------------------------------------------------ */
 
-void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_integer_t min, knh_integer_t max)
+void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_int_t min, knh_int_t max)
 {
 	DP(b)->min = min;
 	DP(b)->max = max;
@@ -136,7 +136,7 @@ void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_integer_t min, knh_integer
 		DP(b)->ffmt = knh_fenumfmt__unsigned;
 		if(DP(b)->min == KNH_UINT_MIN) {
 			if(DP(b)->max == KNH_UINT_MAX) {
-				KNH_ASSERT(DP(b)->fchk == knh_fenumchk__nop);
+				//KNH_ASSERT(DP(b)->fchk == knh_fenumchk__nop);
 			}
 			else {
 				DP(b)->fchk = knh_fenumchk__unsigned_max;
@@ -154,7 +154,7 @@ void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_integer_t min, knh_integer
 	else {
 		if(DP(b)->min == KNH_INT_MIN) {
 			if(DP(b)->max == KNH_INT_MAX) {
-				KNH_ASSERT(DP(b)->fchk == knh_fenumchk__nop);
+				//KNH_ASSERT(DP(b)->fchk == knh_fenumchk__nop);
 			}
 			else {
 				DP(b)->fchk = knh_fenumchk__signed_max;
@@ -173,7 +173,7 @@ void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_integer_t min, knh_integer
 
 /* ------------------------------------------------------------------------ */
 
-void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_integer_t v)
+void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_int_t v)
 {
 	if(!DP(b)->fchk(b, v)) {
 		v = DP(b)->min;
@@ -183,7 +183,7 @@ void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_integer_t v)
 
 /* ------------------------------------------------------------------------ */
 
-IntUnit *new_IntUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *urn, String *tag, knh_integer_t min, knh_integer_t max, knh_integer_t defvalue)
+IntUnit *new_IntUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *urn, String *tag, knh_int_t min, knh_int_t max, knh_int_t defvalue)
 {
 	IntUnit* o = (IntUnit*)new_Object_bcid(ctx, CLASS_IntUnit, 0);
 
@@ -217,11 +217,6 @@ void knh_IntUnit_initId(Ctx *ctx, IntUnit *b, knh_flag_t flag, knh_class_t cid,
 	}
 }
 
-
-/* ======================================================================== */
-/* [default_func] */
-
-
 /* ------------------------------------------------------------------------ */
 
 #ifdef __cplusplus
