@@ -45,31 +45,107 @@ knh_class_t knh_system_loadVocabulary(Ctx *ctx, knh_bytes_t urn);
 /* ======================================================================== */
 /* [constructors] */
 
-NameSpace* new_NameSpace(Ctx *ctx, NameSpace *parent, String *nsname)
+NameSpace* new_NameSpace(Ctx *ctx, String *nsname)
 {
 	knh_NameSpace_t* o = (NameSpace*)new_Object_bcid(ctx, CLASS_NameSpace, KNH_OBJECT_RAWINIT);
-	//DBG2_P("@@@@@@@@ %p, %p %p", o, DP(o), DP(o)->nsname);
 	KNH_INITv(DP(o)->nsname, nsname);
-	KNH_INITv(DP(o)->parent, parent);
-	if(IS_NULL(parent)) {
-		KNH_INITv(DP(o)->name2cidDictSet, new_DictSet(ctx, KONOHA_TCLASS_SIZE));
-	}
-	else{
-		KNH_INITv(DP(o)->name2cidDictSet, new_DictSet(ctx, 64));
-		knh_NameSpace_import(ctx, o, STEXT("konoha"));
-	}
 	return o;
 }
 
+/* ======================================================================== */
+/* [imported namespace] */
+
+void knh_NameSpace_importNameSpace(Ctx *ctx, NameSpace *ns, NameSpace *other)
+{
+	if(IS_NULL(DP(ns)->importedNameSpaces)) {
+		KNH_SETv(ctx, DP(ns)->importedNameSpaces, new_Array0(ctx, 0));
+	}
+	knh_Array_add(ctx, DP(ns)->importedNameSpaces, UP(other));
+}
+
+/* ------------------------------------------------------------------------ */
+
+static
+NameSpace *knh_NameSpace_getImportedNameSpace(Ctx *ctx, NameSpace *ns, size_t n)
+{
+	if(IS_NULL(DP(ns)->importedNameSpaces)) {
+		return NULL;
+	}
+	if(n < knh_Array_size(DP(ns)->importedNameSpaces)) {
+		return (NameSpace*)knh_Array_n(DP(ns)->importedNameSpaces, n);
+	}
+	return NULL;
+}
+
+/* ======================================================================== */
+/* [NameSpace] */
+
+Script *knh_NameSpace_getScript(Ctx *ctx, NameSpace *ns)
+{
+	if(IS_NULL(DP(ns)->script)) {
+		KNH_SETv(ctx, DP(ns)->script, new_Script(ctx, knh_String_tobytes(DP(ns)->nsname)));
+	}
+	return DP(ns)->script;
+}
+
 /* ======================================================================== */
 /* [class] */
 
-/* @ method void NameSpace.seClassTable(String name, Class c) */
-
-void knh_NameSpace_seClassTable(Ctx *ctx, NameSpace *o, String *name, knh_class_t c)
+knh_class_t konoha_getcid(Ctx *ctx, knh_bytes_t lname)
 {
-	KNH_ASSERT(IS_NameSpace(o));
-	KNH_ASSERT(IS_String(name));
+	knh_uintptr_t cid = knh_DictSet_get__b(DP(ctx->sys)->ClassNameDictSet, lname);
+	if(cid > 0) return (knh_class_t)(cid-1);
+	return CLASS_unknown;
+}
+
+/* ------------------------------------------------------------------------ */
+
+knh_class_t konoha_findcid(Ctx *ctx, knh_bytes_t lname)
+{
+	knh_class_t cid = konoha_getcid(ctx, lname);
+	if(cid != CLASS_unknown) {
+		return cid;
+	}
+	if(knh_bytes_endsWith(lname, STEXT("[]"))) {
+		lname.len -= 2;
+		cid = konoha_getcid(ctx, lname);
+		if(cid == CLASS_unknown || knh_class_isPrivate(cid)) {
+			return CLASS_Array;
+		}
+		return knh_class_Array(ctx, cid);
+	}
+	if(knh_bytes_endsWith(lname, STEXT(".."))) {
+		lname.len -= 2;
+		cid = konoha_getcid(ctx, lname);
+		if(cid == CLASS_unknown || knh_class_isPrivate(cid)) {
+			return CLASS_Iterator;
+		}
+		return knh_class_Iterator(ctx, cid);
+	}
+	if(lname.buf[lname.len-1] == '}') {
+		knh_index_t loc = knh_bytes_index(lname, '{');
+		if(loc != -1) {
+			knh_bytes_t urn = knh_bytes_last(lname, loc+1); urn.len -= 1;
+			urn = knh_Runtime_aliasURN(ctx, urn);
+			knh_class_t bcid = konoha_getcid(ctx, knh_bytes_first(lname, loc));
+			DBG2_P("cid=%d,%s", bcid, CLASSN(bcid));
+			ClassSpec *cs = (ClassSpec*)konoha_getClassSpec(ctx, bcid, urn);
+			if(IS_NOTNULL(cs)) {
+				KNH_SETv(ctx, DP(cs)->urn, new_String(ctx, urn, NULL));
+				return KNH_XCLASS(ctx, DP(cs)->cid, bcid, cs);
+			}
+			return bcid;
+		}
+	}
+	return cid;
+}
+
+/* ------------------------------------------------------------------------ */
+
+void knh_NameSpace_setcid(Ctx *ctx, NameSpace *o, String *name, knh_class_t c)
+{
+	DBG2_ASSERT(IS_NameSpace(o));
+	DBG2_ASSERT(IS_String(name));
 	knh_DictSet_set(ctx, DP(o)->name2cidDictSet, name, (knh_uintptr_t)(c+1));
 }
 
@@ -85,7 +161,7 @@ knh_bytes_t knh_NameSpace_firstType(Ctx *ctx, NameSpace *o, knh_bytes_t name, kn
 		if(ch == ')' || ch == '>') level--;
 		if((ch == ',' && level == 1) ||((ch == '>' || ch == ')') && level == 0)) {
 			knh_bytes_t t = {name.buf, i};
-			*type = knh_NameSpace_getType(ctx, o, t);
+			*type = knh_NameSpace_gettype(ctx, o, t, 0);
 			if(*type == CLASS_unknown) {
 				*type = TYPE_Any;
 			}
@@ -97,56 +173,6 @@ knh_bytes_t knh_NameSpace_firstType(Ctx *ctx, NameSpace *o, knh_bytes_t name, kn
 	return STEXT("");
 }
 
-
-/* ------------------------------------------------------------------------ */
-/* @ method Class NameSpace.geClassTable(String name) */
-
-knh_class_t knh_NameSpace_geClassTable(Ctx *ctx, NameSpace *o, knh_bytes_t name)
-{
-	if(knh_bytes_equals(name, STEXT("Script")) && IS_NOTNULL(DP(o)->script)) {
-		return knh_Object_cid(DP(o)->script);
-	}
-	if(knh_bytes_equals(name, STEXT("This"))) {
-		return CLASS_This;
-	}
-
-	{
-		NameSpace *ns = o;
-		while(1) {
-			knh_uintptr_t cid = knh_DictSet_get__b(DP(ns)->name2cidDictSet, name);
-			if(cid > 0) return (knh_class_t)(cid-1);
-			if(IS_NULL(DP(ns)->parent)) {
-				goto L_GENPART;
-			}
-			ns = DP(ns)->parent;
-		}
-	}
-
-	L_GENPART:
-	if(o != knh_rootNameSpace) {
-		knh_index_t loc = knh_bytes_index(name, '<');
-		if(loc > 0) {
-			knh_class_t bcid = knh_NameSpace_geClassTable(ctx, o, knh_bytes_first(name, loc));
-			KNH_ASSERT_cid(bcid);
-			if(!knh_Class_isGenerics(bcid)) return bcid;
-			knh_class_t p1 = CLASS_Any, p2 = ctx->share->ClassTable[bcid].p2;
-			name = knh_NameSpace_firstType(ctx, o, knh_bytes_last(name, loc+1), &p1);
-			knh_NameSpace_firstType(ctx, o, name, &p2);
-			return knh_class_Generics(ctx, bcid, CLASS_type(p1), CLASS_type(p2));
-		}
-		loc = knh_bytes_index(name, '(');
-		if(loc > 0) {
-			knh_type_t r0 = knh_NameSpace_getType(ctx, o, knh_bytes_first(name, loc));
-			knh_type_t t1 = TYPE_void, t2 = TYPE_void, t3 = TYPE_void;
-			name = knh_NameSpace_firstType(ctx, o, knh_bytes_last(name, loc+1), &t1);
-			name = knh_NameSpace_firstType(ctx, o, name, &t2);
-			knh_NameSpace_firstType(ctx, o, name, &t3);
-			return knh_class_Closure(ctx, r0, t1, t2, t3);
-		}
-	}
-	return CLASS_unknown;
-}
-
 /* ------------------------------------------------------------------------ */
 
 void knh_NameSpace_setLocalName(Ctx *ctx, NameSpace *o, knh_class_t cid)
@@ -158,6 +184,70 @@ void knh_NameSpace_setLocalName(Ctx *ctx, NameSpace *o, knh_class_t cid)
 
 /* ------------------------------------------------------------------------ */
 
+knh_class_t knh_NameSpace_getcid(Ctx *ctx, NameSpace *o, knh_bytes_t name)
+{
+	if(knh_bytes_equals(name, STEXT("This"))) return CLASS_This;
+	if(knh_bytes_equals(name, STEXT("Script"))) {
+		Script *scr = knh_NameSpace_getScript(ctx, o);
+		return knh_Object_cid(scr);
+	}
+
+	{
+		size_t i = 0;
+		knh_uintptr_t cididx = knh_DictSet_get__b(DP(o)->name2cidDictSet, name);
+		if(cididx > 0) return (knh_class_t)(cididx-1);
+		NameSpace *ins = NULL;
+		while((ins = knh_NameSpace_getImportedNameSpace(ctx, o, i++)) != NULL) {
+			cididx = knh_DictSet_get__b(DP(ins)->name2cidDictSet, name);
+			if(cididx > 0) return (knh_class_t)(cididx-1);
+		}
+	}
+
+	{
+		knh_class_t cid = konoha_getcid(ctx, name);
+		if(cid != CLASS_unknown) {
+			knh_NameSpace_setLocalName(ctx, o, cid);
+			return cid;
+		}
+	}
+
+	{
+		knh_index_t loc = knh_bytes_index(name, '<');
+		if(loc > 0) {
+			knh_class_t bcid = knh_NameSpace_getcid(ctx, o, knh_bytes_first(name, loc));
+			KNH_ASSERT_cid(bcid);
+			if(!knh_Class_isGenerics(bcid)) return bcid;
+			knh_class_t p1 = CLASS_Any, p2 = ctx->share->ClassTable[bcid].p2;
+			knh_bytes_t nsub = knh_NameSpace_firstType(ctx, o, knh_bytes_last(name, loc+1), &p1);
+			knh_NameSpace_firstType(ctx, o, nsub, &p2);
+			knh_class_t cid = knh_class_Generics(ctx, bcid, CLASS_type(p1), CLASS_type(p2));
+			if(cid != CLASS_unknown) {
+				knh_NameSpace_setcid(ctx, o, new_String(ctx, name, NULL), cid);
+				knh_NameSpace_setLocalName(ctx, o, cid);
+			}
+			return cid;
+		}
+
+		loc = knh_bytes_index(name, '(');
+		if(loc > 0) {
+			knh_type_t r0 = knh_NameSpace_gettype(ctx, o, knh_bytes_first(name, loc), 0);
+			knh_type_t t1 = TYPE_void, t2 = TYPE_void, t3 = TYPE_void;
+			knh_bytes_t nsub = knh_NameSpace_firstType(ctx, o, knh_bytes_last(name, loc+1), &t1);
+			name = knh_NameSpace_firstType(ctx, o, nsub, &t2);
+			knh_NameSpace_firstType(ctx, o, nsub, &t3);
+			knh_class_t cid = knh_class_Closure(ctx, r0, t1, t2, t3);
+			if(cid != CLASS_unknown) {
+				knh_NameSpace_setcid(ctx, o, new_String(ctx, name, NULL), cid);
+				knh_NameSpace_setLocalName(ctx, o, cid);
+			}
+			return cid;
+		}
+	}
+	return CLASS_unknown;
+}
+
+/* ------------------------------------------------------------------------ */
+
 char* knh_Context_CLASSN(Ctx *ctx, knh_class_t cid)
 {
 	KNH_ASSERT_cid(cid);
@@ -166,7 +256,8 @@ char* knh_Context_CLASSN(Ctx *ctx, knh_class_t cid)
 		return knh_String_tochar(ctx->share->ClassTable[cid].sname);
 	}
 	else {
-		knh_uintptr_t cid2 = knh_DictSet_get__b(DP(ctx->ns)->name2cidDictSet, knh_String_tobytes(ctx->share->ClassTable[cid].sname));
+		knh_uintptr_t cid2 =
+			knh_DictSet_get__b(DP(ctx->ns)->name2cidDictSet, knh_String_tobytes(ctx->share->ClassTable[cid].sname));
 		if(cid2 > 0 && cid == cid2 - 1) {
 			return knh_String_tochar(ctx->share->ClassTable[cid].sname);
 		}
@@ -179,18 +270,20 @@ char* knh_Context_CLASSN(Ctx *ctx, knh_class_t cid)
 
 /* ------------------------------------------------------------------------ */
 
-void knh_NameSpace_import(Ctx *ctx, NameSpace *o, knh_bytes_t p)
+void knh_NameSpace_importClass(Ctx *ctx, NameSpace *o, knh_bytes_t pkgname)
 {
 	size_t i;
-	if(p.buf[p.len-1] == '.') {
-		p.len--;
+	if(pkgname.buf[pkgname.len-1] == '.') {
+		pkgname.len--;
 	}
 	for(i = 0; i < KNH_TCLASS_SIZE; i++) {
 		if(ctx->share->ClassTable[i].sname == NULL) continue;
 		KNH_ASSERT(IS_bString(ctx->share->ClassTable[i].lname));
 		if(knh_class_isPrivate(i)) continue;
 		knh_bytes_t cname = knh_String_tobytes(ctx->share->ClassTable[i].lname);
-		if(knh_bytes_startsWith(cname, p) && cname.buf[p.len] == '.' && isupper(cname.buf[p.len+1])) {
+		if(knh_bytes_startsWith(cname, pkgname)
+				&& cname.buf[pkgname.len] == '.'
+					&& isupper(cname.buf[pkgname.len+1])) {
 			knh_NameSpace_setLocalName(ctx, o, (knh_class_t)i);
 		}
 	}
@@ -199,34 +292,104 @@ void knh_NameSpace_import(Ctx *ctx, NameSpace *o, knh_bytes_t p)
 /* ======================================================================== */
 /* [type] */
 
-static
-knh_bool_t knh_bytes_isNotNullType(knh_bytes_t t)
+knh_type_t knh_NameSpace_gettype(Ctx *ctx, NameSpace *ns, knh_bytes_t name, int isNullable)
 {
-	if(t.len > 2 && t.buf[t.len-1] == '!' && t.buf[t.len-2] != '!') {
-		return 1;
+	if(name.buf[0] == 'v') {
+		if(name.len == 4 && name.buf[1] == 'o' &&
+			name.buf[2] == 'i' && name.buf[3] == 'd') return TYPE_void;
+		if(name.len == 3 && name.buf[1] == 'a' && name.buf[2] == 'r') return TYPE_var;
 	}
-	return 0;
+
+	if(name.len > 2 && name.buf[name.len-1] == '!') {
+		name.len--;
+		isNullable = 0;
+	}
+
+	if(name.len > 2 && name.buf[name.len-1] == '?') {
+		name.len--;
+		isNullable = 1;
+	}
+
+	{
+		knh_class_t cid = knh_NameSpace_getcid(ctx, ns, name);
+		if(cid != CLASS_unknown && !isNullable) return NNTYPE_cid(cid);
+		return cid;
+	}
+}
+
+/* ======================================================================== */
+/* [const] */
+
+Object *
+knh_NameSpace_getConstNULL(Ctx *ctx, NameSpace *ns, knh_bytes_t name)
+{
+	knh_index_t idx = knh_bytes_index(name, '.');
+	if(idx > 0) {
+		knh_class_t cid = knh_NameSpace_getcid(ctx, ns, knh_bytes_first(name, idx));
+		if(cid == CLASS_unknown) return NULL;
+		return konoha_getClassConstNULL(ctx, cid, knh_bytes_last(name, idx+1));
+	}
+	if(knh_bytes_index(name, '_') == -1) {
+		if(IS_NOTNULL(DP(ns)->lconstDictMap)) {
+			idx = knh_DictMap_index__b(DP(ns)->lconstDictMap, name);
+			if(idx != -1) return knh_DictMap_valueAt(DP(ns)->lconstDictMap, idx);
+		}
+		size_t i = 0;
+		NameSpace *ins = NULL;
+		while((ins = knh_NameSpace_getImportedNameSpace(ctx, ns, i++)) != NULL) {
+			if(IS_NOTNULL(DP(ins)->lconstDictMap)) {
+				idx = knh_DictMap_index__b(DP(ins)->lconstDictMap, name);
+				if(idx != -1) return knh_DictMap_valueAt(DP(ins)->lconstDictMap, idx);
+			}
+		}
+		return NULL;
+	}
+	return konoha_getClassConstNULL(ctx, CLASS_Any, name);
 }
 
 /* ------------------------------------------------------------------------ */
 
-knh_type_t knh_NameSpace_getType(Ctx *ctx, NameSpace *o, knh_bytes_t name)
+void knh_NameSpace_addConst(Ctx *ctx, NameSpace *ns, String *name, Object *value)
 {
-	if(name.len == 4 &&
-		name.buf[0] == 'v' && name.buf[1] == 'o' &&
-		name.buf[2] == 'i' && name.buf[3] == 'd') return TYPE_void;
-
-	if(knh_bytes_isNotNullType(name)) {
-		knh_class_t cid;
-		name.len--;
-		cid = knh_NameSpace_geClassTable(ctx, o, name);
-		return (cid == CLASS_unknown) ? cid : NNTYPE_cid(cid);
+	KNH_ASSERT(IS_NameSpace(ns));
+	KNH_ASSERT(IS_String(name));
+	if(knh_bytes_index(knh_String_tobytes(name), '_') == -1) {
+		if(IS_NULL(DP(ns)->lconstDictMap)) {
+			KNH_SETv(ctx, DP(ns)->lconstDictMap, new_DictMap0(ctx, 16));
+		}
+		knh_DictMap_set(ctx, DP(ns)->lconstDictMap, name, value);
 	}
 	else {
-		return knh_NameSpace_geClassTable(ctx, o, name);
+		konoha_addClassConst(ctx, CLASS_Any, name, value);
 	}
 }
 
+/* ======================================================================== */
+/* [Func] */
+
+void knh_NameSpace_setFuncClass(Ctx *ctx, NameSpace *o, knh_methodn_t mn, knh_class_t c)
+{
+	KNH_ASSERT(IS_NameSpace(o));
+	if(IS_NULL(DP(o)->func2cidDictSet)) {
+		KNH_SETv(ctx, DP(o)->func2cidDictSet, new_DictSet(ctx, 16));
+	}
+	knh_DictSet_set(ctx, DP(o)->func2cidDictSet, new_String__mn(ctx, mn), (knh_uintptr_t)(c+1));
+}
+
+/* ------------------------------------------------------------------------ */
+
+knh_class_t
+knh_NameSpace_getFuncClass(Ctx *ctx, NameSpace *o, knh_bytes_t funcname)
+{
+	if(IS_NOTNULL(DP(o)->func2cidDictSet)) {
+		knh_uintptr_t cid = knh_DictSet_get__b(DP(o)->func2cidDictSet, funcname);
+		if(cid != 0) {
+			return (knh_class_t)(cid-1);
+		}
+	}
+	return CLASS_unknown; /* if it isn't found */
+}
+
 /* ======================================================================== */
 /* [tag] */
 
@@ -234,7 +397,7 @@ knh_class_t knh_tclass_classURN(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn)
 {
 	char buf[CLASSNAME_BUFSIZ];
 	knh_snprintf(buf, sizeof(buf), KNH_CLASSSPEC_FMT, CLASSN(bcid), urn.buf);
-	knh_class_t cid = knh_NameSpace_geClassTable(ctx, knh_rootNameSpace, B(buf));
+	knh_class_t cid = konoha_getcid(ctx, B(buf));
 	if(cid == CLASS_unknown) {
 		cid = knh_tclass_loadURN(ctx, bcid, urn);
 	}
@@ -263,93 +426,20 @@ knh_class_t knh_tclass_loadURN(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn)
 knh_type_t knh_NameSpace_tagcid(Ctx *ctx, NameSpace *o, knh_class_t bcid, knh_bytes_t tag)
 {
 	TODO();
-	//	char buf[CLASSNAME_BUFSIZ];
+//	char buf[CLASSNAME_BUFSIZ];
 //	DBG2_P("%s:'%s'", CLASSN(bcid), tag.buf);
 //	knh_snprintf(buf, sizeof(buf), "%s:%s", CLASSN(bcid), tag.buf);
-//	knh_class_t cid = knh_NameSpace_geClassTable(ctx, o, B(buf));
+//	knh_class_t cid = knh_NameSpace_getClass(ctx, o, B(buf));
 //	if(cid == CLASS_unknown) {
 //		if(bcid == CLASS_Int) {
 //			knh_snprintf(buf, sizeof(buf), "Float:%s", tag.buf);
-//			cid = knh_NameSpace_geClassTable(ctx, o, B(buf));
+//			cid = knh_NameSpace_getClass(ctx, o, B(buf));
 //		}
 //	}
 //	return cid;
 	return CLASS_unknown;
 }
 
-/* ======================================================================== */
-/* [func] */
-
-void knh_NameSpace_setFuncClass(Ctx *ctx, NameSpace *o, knh_methodn_t mn, knh_class_t c)
-{
-	KNH_ASSERT(IS_NameSpace(o));
-	if(IS_NULL(DP(o)->func2cidDictSet)) {
-		KNH_SETv(ctx, DP(o)->func2cidDictSet, new_DictSet(ctx, 16));
-	}
-	knh_DictSet_set(ctx, DP(o)->func2cidDictSet, new_String__mn(ctx, mn), (knh_uintptr_t)(c+1));
-}
-
-/* ------------------------------------------------------------------------ */
-
-knh_class_t
-knh_NameSpace_getFuncClass(Ctx *ctx, NameSpace *o, knh_bytes_t funcname)
-{
-	if(IS_NOTNULL(DP(o)->func2cidDictSet)) {
-		knh_uintptr_t cid = knh_DictSet_get__b(DP(o)->func2cidDictSet, funcname);
-		if(cid != 0) {
-			return (knh_class_t)(cid-1);
-		}
-	}
-	return CLASS_unknown; /* if it isn't found */
-}
-
-/* ======================================================================== */
-/* [const] */
-
-knh_bool_t
-knh_NameSpace_existsConst(Ctx *ctx, NameSpace *o, knh_bytes_t name)
-{
-	if(knh_bytes_index(name, '_') == -1) {
-		if(IS_NOTNULL(DP(o)->lconstDictMap)) {
-			return (knh_DictMap_index__b(DP(o)->lconstDictMap, name) != -1);
-		}
-		return 0;
-	}
-	return konoha_existsConst(ctx, name);
-}
-
-/* ------------------------------------------------------------------------ */
-
-void knh_NameSpace_addConst(Ctx *ctx, NameSpace *o, String *name, Object *value)
-{
-	KNH_ASSERT(IS_NameSpace(o));
-	KNH_ASSERT(IS_String(name));
-	if(knh_bytes_index(knh_String_tobytes(name), '_') == -1) {
-		if(IS_NULL(DP(o)->lconstDictMap)) {
-			KNH_SETv(ctx, DP(o)->lconstDictMap, new_DictMap0(ctx, 16));
-		}
-		knh_DictMap_set(ctx, DP(o)->lconstDictMap, name, value);
-	}
-	else {
-		konoha_addConst(ctx, name, value);
-	}
-}
-
-
-/* ------------------------------------------------------------------------ */
-
-Object*
-knh_NameSpace_getConst(Ctx *ctx, NameSpace *o, knh_bytes_t name)
-{
-	if(knh_bytes_index(name, '_') == -1) {
-		if(IS_NOTNULL(DP(o)->lconstDictMap)) {
-			return knh_DictMap_get__b(ctx,  DP(o)->lconstDictMap, name);
-		}
-		return (Object*)KNH_NULL;
-	}
-	return konoha_getConst(ctx, name);
-}
-
 
 /* ------------------------------------------------------------------------ */
 
