@@ -142,12 +142,13 @@ void knh_Asm_prepare(Ctx *ctx, Asm *abr, Method *mtd, Stmt *stmt)
 //		DP(abr)->vars[i].count = 0;
 		KNH_SETv(ctx, DP(abr)->vars[i].value, KNH_NULL);
 	}
+	knh_Asm_initReg(ctx, abr);
 	DP(abr)->nnrtti  = 0;
 	DP(abr)->nnrtti0 = 0;
 
-	knh_Array_clear(ctx, DP(abr)->registeredStmts);
 	DP(abr)->stack = 1;
 	DP(abr)->globalidx = -1;
+
 	DP(abr)->llstep = 0;
 	for(i = 0; i < DP(abr)->labelmax; i++) {
 		KNH_SETv(ctx, DP(abr)->labels[i].tklabel, KNH_NULL);
@@ -194,7 +195,7 @@ void knh_Asm_gc(Ctx *ctx, Asm *abr)
 
 		KNH_SETv(ctx, DP(abr)->vars[i].value, KNH_NULL);
 	}
-	knh_Array_clear(ctx, DP(abr)->registeredStmts);
+	knh_Asm_initReg(ctx, abr);
 	for(i = 0; i < DP(abr)->labelmax; i++) {
 		KNH_SETv(ctx, DP(abr)->labels[i].tklabel, KNH_NULL);
 	}
@@ -412,12 +413,12 @@ static
 void KNH_ASM_BOX(Ctx *ctx, Asm *abr, knh_type_t atype, int a)
 {
 	if(knh_rtti_issync(abr, a)) return;
-	DBG2_P("@@@ atype=%s%s", TYPEQN(atype));
 	knh_class_t cid = CLASS_type(atype);
 	KNH_ASSERT_cid(cid);
 	knh_class_t bcid = ctx->share->ClassTable[cid].bcid;
 	if(bcid == CLASS_Boolean || bcid == CLASS_Int || bcid == CLASS_Float) {
 		if(IS_NNTYPE(atype)) {
+			DBG2_P("@@@ atype=%s%s", TYPEQN(atype));
 			KNH_ASM_BOX_(ctx, abr, a, cid);
 		}
 		else {
@@ -451,13 +452,35 @@ void KNH_ASM_NNBOX(Ctx *ctx, Asm *abr, knh_type_t atype, int a)
 static
 void KNH_ASM_SMOVx(Ctx *ctx, Asm *abr, knh_type_t atype, int a, knh_type_t btype, knh_sfx_t bx)
 {
+#ifdef KNH_USING_UNBOXFIELD
+	if(btype == NNTYPE_Int) {
+		KNH_ASM_MOVxi_(ctx, abr, sfi_(a), bx);
+		if(!IS_NNTYPE(atype)) {
+			KNH_ASM_NNBOX_(ctx, abr, sfi_(a), CLASS_type(btype));
+		}
+		return;
+	}
+	if(btype == NNTYPE_Float) {
+		KNH_ASM_MOVxf_(ctx, abr, sfi_(a), bx);
+		if(!IS_NNTYPE(atype)) {
+			KNH_ASM_NNBOX_(ctx, abr, sfi_(a), CLASS_type(btype));
+		}
+		return;
+	}
+	if(btype == NNTYPE_Boolean) {
+		KNH_ASM_MOVxb_(ctx, abr, sfi_(a), bx);
+		if(!IS_NNTYPE(atype)) {
+			KNH_ASM_NNBOX_(ctx, abr, sfi_(a), CLASS_type(btype));
+		}
+		return;
+	}
+#endif
 	if(IS_NNTYPE(atype) && !IS_NNTYPE(btype)) {
 		KNH_ASM_ISNULLx_(ctx, abr, bx);
 		btype = NNTYPE_cid(btype);
 	}
 	knh_rtti_async(abr, a);
 	KNH_ASM_MOVx_(ctx, abr, sfi_(a), bx);
-	//KNH_ASM_UNBOX(ctx, abr, atype, a);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -559,6 +582,47 @@ void KNH_ASM_SMOV(Ctx *ctx, Asm *abr, knh_type_t atype, int a, Token *tkb)
 
 /* ------------------------------------------------------------------------ */
 
+static
+void KNH_ASM_XMOVx(Ctx *ctx, Asm *abr, knh_type_t atype, knh_sfx_t ax, knh_type_t btype, knh_sfx_t bx)
+{
+	if(IS_NNTYPE(atype) && !IS_NNTYPE(btype)) {
+		KNH_ASM_ISNULLx_(ctx, abr, bx);
+	}
+	if(atype == NNTYPE_Int) {
+		if(btype == NNTYPE_Int) {
+			KNH_ASM_XMOVxi_(ctx, abr, ax, bx);
+		}
+		else {
+			KNH_ASM_XMOVxio_(ctx, abr, ax, bx);
+		}
+		return;
+	}
+	if(atype == NNTYPE_Float) {
+		if(btype == NNTYPE_Float) {
+			KNH_ASM_XMOVxf_(ctx, abr, ax, bx);
+		}
+		else {
+			KNH_ASM_XMOVxfo_(ctx, abr, ax, bx);
+		}
+		return;
+	}
+	if(atype == NNTYPE_Boolean && btype == NNTYPE_Boolean) {
+		KNH_ASM_XMOVxb_(ctx, abr, ax, bx);
+		return;
+	}
+	if(atype == TYPE_Int && btype == NNTYPE_Int) {
+		KNH_ASM_XMOVxBXi_(ctx, abr, ax, bx, CLASS_type(btype));
+		return;
+	}
+	if(atype == TYPE_Int && btype == NNTYPE_Int) {
+		KNH_ASM_XMOVxBXf_(ctx, abr, ax, bx, CLASS_type(btype));
+		return;
+	}
+	KNH_ASM_XMOVx_(ctx, abr, ax, bx);
+}
+
+/* ------------------------------------------------------------------------ */
+
 static
 void KNH_ASM_XMOV(Ctx *ctx, Asm *abr, knh_type_t atype, int a, size_t an, Token *tkb)
 {
@@ -569,6 +633,20 @@ void KNH_ASM_XMOV(Ctx *ctx, Asm *abr, knh_type_t atype, int a, size_t an, Token
 		case TT_CLASSID:
 		case TT_CONST: {
 			Object *v = DP(tkb)->data;
+#ifdef KNH_USING_UNBOXFIELD
+			if(atype == NNTYPE_Int) {
+				KNH_ASM_XMOVoi_(ctx, abr, ax, v);
+				break;
+			}
+			if(atype == NNTYPE_Float) {
+				KNH_ASM_XMOVof_(ctx, abr, ax, v);
+				break;
+			}
+			if(atype == NNTYPE_Boolean) {
+				KNH_ASM_XMOVob_(ctx, abr, ax, v);
+				break;
+			}
+#endif/*KNU_USING_UNBOXFIED*/
 			KNH_ASM_XMOVo_(ctx, abr, ax, v);
 			break;
 		}
@@ -579,44 +657,63 @@ void KNH_ASM_XMOV(Ctx *ctx, Asm *abr, knh_type_t atype, int a, size_t an, Token
 				KNH_ASM_ISNULL_(ctx, abr, b);
 				knh_rtti_nullChecked(abr, b);
 			}
+#ifdef KNH_USING_UNBOXFIELD
+			if(atype == NNTYPE_Int) {
+				KNH_ASM_XMOVsi_(ctx, abr, ax, sfi_(b));
+				break;
+			}
+			if(atype == NNTYPE_Float) {
+				KNH_ASM_XMOVsf_(ctx, abr, ax, sfi_(b));
+				break;
+			}
+			if(atype == NNTYPE_Boolean) {
+				KNH_ASM_XMOVsb_(ctx, abr, ax, sfi_(b));
+				break;
+			}
+#endif/*KNU_USING_UNBOXFIED*/
 			KNH_ASM_BOX(ctx, abr, btype, b);
 			KNH_ASM_XMOVs_(ctx, abr, ax, sfi_(b));
-			break; /* int <=> float */
+			break;
 		}
 
 		case TT_FIELD: {
 			int b = (int)DP(tkb)->index;
 			knh_sfx_t bx = {(knh_sfi_t)0, (size_t)b};
-			if(IS_NNTYPE(atype) && !IS_NNTYPE(btype)) {
-				KNH_ASM_ISNULLx_(ctx, abr, bx);
-			}
-			KNH_ASM_XMOVx_(ctx, abr, ax, bx);
-			break; /* int <=> float */
+			KNH_ASM_XMOVx(ctx, abr, atype, ax, btype, bx);
+			break;
 		}
 
 		case TT_GLOBAL: {
 			int b = (int)DP(tkb)->index;
 			knh_sfx_t bx = {(knh_sfi_t)DP(abr)->globalidx, (size_t)b};
 			KNH_ASM_ASSERT(ctx, abr, bx.i != -1);
-			if(IS_NNTYPE(atype) && !IS_NNTYPE(btype)) {
-				KNH_ASM_ISNULLx_(ctx, abr, bx);
-			}
-			KNH_ASM_XMOVx_(ctx, abr, ax, bx);
-			break; /* int <=> float */
+			KNH_ASM_XMOVx(ctx, abr, atype, ax, btype, bx);
+			break;
 		}
 
 		case TT_MEMBER : {
 			int idx = (int)DP(tkb)->index;
 			size_t b = (size_t)(DP(tkb)->num)->n.ivalue;
 			knh_sfx_t bx = {sfi_(idx), b};
-			if(IS_NNTYPE(atype) && !IS_NNTYPE(btype)) {
-				KNH_ASM_ISNULLx_(ctx, abr, bx);
-			}
-			KNH_ASM_XMOVx_(ctx, abr, ax, bx);
+			KNH_ASM_XMOVx(ctx, abr, atype, ax, btype, bx);
 			break;
 
 		}
 		case TT_DEFVAL: {
+#ifdef KNH_USING_UNBOXFIELD
+			if(atype == NNTYPE_Int) {
+				KNH_ASM_XMOVoi_(ctx, abr, ax, UP(KNH_INT0));
+				break;
+			}
+			if(atype == NNTYPE_Float) {
+				KNH_ASM_XMOVof_(ctx, abr, ax, UP(KNH_FLOAT0));
+				break;
+			}
+			if(atype == NNTYPE_Boolean) {
+				KNH_ASM_XMOVob_(ctx, abr, ax, KNH_FALSE);
+				break;
+			}
+#endif/*KNU_USING_UNBOXFIED*/
 			knh_class_t cid = DP(tkb)->cid;
 			KNH_ASM_XMOVDEF_(ctx, abr, ax, cid);
 			break;
@@ -940,7 +1037,7 @@ static
 void TERMs_ASM_JIFNUL(Ctx *ctx, Stmt *stmt, size_t n, Asm *abr, knh_labelid_t label)
 {
 	Token *tk = DP(stmt)->tokens[n];
-	if(IS_Token(tk) && SP(tk)->tt == TT_LOCAL) {
+	if(IS_Token(tk) && SP(tk)->tt == TT_STACK /*TT_LOCAL ??*/) {
 		KNH_ASM_JIFNUL_(ctx, abr, label, sfi_(DP(tk)->index));
 	}
 	else {
@@ -955,7 +1052,7 @@ static
 void TERMs_ASM_JIFNN(Ctx *ctx, Stmt *stmt, size_t n, Asm *abr, knh_labelid_t label)
 {
 	Token *tk = DP(stmt)->tokens[n];
-	if(IS_Token(tk) && SP(tk)->tt == TT_LOCAL) {
+	if(IS_Token(tk) && SP(tk)->tt == TT_STACK /*TT_LOCAL ??*/) {
 		KNH_ASM_JIFNN_(ctx, abr, label, sfi_(DP(tk)->index));
 	}
 	else {
@@ -970,7 +1067,7 @@ static
 void TERMs_ASM_JIFF(Ctx *ctx, Stmt *stmt, size_t n, Asm *abr, knh_labelid_t label)
 {
 	Token *tk = DP(stmt)->tokens[n];
-	if(IS_Token(tk) && SP(tk)->tt == TT_LOCAL) {
+	if(IS_Token(tk) && SP(tk)->tt == TT_STACK /*TT_LOCAL ??*/) {
 		KNH_ASM_bJIFF_(ctx, abr, label, sfi_(DP(tk)->index));
 	}
 	else {
@@ -994,7 +1091,7 @@ static
 void TERMs_ASM_JIFF_LOOP(Ctx *ctx, Stmt *stmt, size_t n, Asm *abr, knh_labelid_t label)
 {
 	Token *tk = DP(stmt)->tokens[n];
-	if(IS_Token(tk) && SP(tk)->tt == TT_LOCAL) {
+	if(IS_Token(tk) && SP(tk)->tt == TT_STACK /*TT_LOCAL ??*/) {
 		KNH_ASM_bJIFF_(ctx, abr, label, sfi_(DP(tk)->index));
 	}
 	else {
@@ -1018,7 +1115,7 @@ static
 void TERMs_ASM_JIFT(Ctx *ctx, Stmt *stmt, size_t n, Asm *abr, knh_labelid_t label)
 {
 	Token *tk = DP(stmt)->tokens[n];
-	if(IS_Token(tk) && SP(tk)->tt == TT_LOCAL) {
+	if(IS_Token(tk) && SP(tk)->tt == TT_STACK /*TT_LOCAL ??*/) {
 		KNH_ASM_bJIFT_(ctx, abr, label, sfi_(DP(tk)->index));
 	}
 	else {
@@ -1042,7 +1139,7 @@ static
 void TERMs_ASM_THROW(Ctx *ctx, Stmt *stmt, size_t n, Asm *abr)
 {
 	Token *tk = DP(stmt)->tokens[n];
-	if(IS_Token(tk) && SP(tk)->tt == TT_LOCAL) {
+	if(IS_Token(tk) && SP(tk)->tt == TT_STACK /*TT_LOCAL ??*/) {
 		KNH_ASM_THROW_(ctx, abr, sfi_(DP(tk)->index));
 	}
 	else {
@@ -2193,6 +2290,16 @@ void knh_Stmt_asmBLOCK(Ctx *ctx, Stmt *stmt, Asm *abr, int isIteration)
 			knh_Stmt_asmBLOCK(ctx, DP(stmt)->stmts[0], abr, 1); break;
 		case STT_LET:
 			knh_StmtLET_asm(ctx, cur, abr, TYPE_void, DP(abr)->stack); break;
+		case STT_REGISTER:
+		{
+			size_t i;
+			for(i = 0; i < DP(cur)->size; i++) {
+				if(IS_Stmt(DP(cur)->terms[i]) && SP(DP(cur)->stmts[i])->stt == STT_LET) {
+					knh_StmtLET_asm(ctx, DP(cur)->stmts[i], abr, TYPE_void, DP(abr)->stack);
+				}
+			}
+			break;
+		}
 		case STT_IF:
 			knh_StmtIF_asm(ctx, cur, abr); break;
 		case STT_SWITCH:
@@ -2262,6 +2369,8 @@ void KNH_ASM_INITLOCAL(Ctx *ctx, Asm *abr)
 //	}
 
 	for(; i < DP(abr)->vars_size; i++) {
+		DBG2_P("LOCAL VARIABLE %s%s %s", TYPEQN(DP(abr)->vars[i].type), FIELDN(DP(abr)->vars[i].fn));
+		if(DP(abr)->vars[i].type == TYPE_void) continue;
 		if(IS_NNTYPE(DP(abr)->vars[i].type)) {
 			if(IS_NULL(DP(abr)->vars[i].value)) {
 				KNH_ASM_MOVDEF_(ctx, abr, sfi_(i), CLASS_type(DP(abr)->vars[i].type));
