@@ -145,7 +145,7 @@ int knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	char bufn[CLASSNAME_BUFSIZ];
 	knh_snprintf(bufn, sizeof(bufn), "%s.%s", knh_String_tochar(DP(ns)->nsname), sToken(StmtCLASS_class(stmt)));
 
-	knh_class_t cid  = knh_NameSpace_geClassTable(ctx, ns, B(bufn));
+	knh_class_t cid  = knh_NameSpace_getcid(ctx, ns, B(bufn));
 	if(cid == CLASS_unknown) {
 		cid = knh_ClassTable_newId(ctx);
 		KNH_ASSERT(ctx->share->ClassTable[cid].class_cid == NULL);
@@ -161,7 +161,7 @@ int knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		supcid = CLASS_Object;
 	}
 	else {
-		supcid = knh_NameSpace_geClassTable(ctx, ns, knh_Token_tobytes(ctx, StmtCLASS_superclass(stmt)));
+		supcid = knh_NameSpace_getcid(ctx, ns, knh_Token_tobytes(ctx, StmtCLASS_superclass(stmt)));
 		if(supcid == CLASS_unknown) {
 			knh_Asm_perror(ctx, abr, KMSG_UCLASSN, NULL);
 			supcid = CLASS_Object;
@@ -193,10 +193,10 @@ int knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		TC->offset = ctx->share->ClassTable[supcid].bsize;
 	}
 	KNH_ASSERT(TC->class_cid == NULL);
-	konoha_seClassTableName(ctx, cid, new_String(ctx, B(bufn), NULL));
+	konoha_setClassName(ctx, cid, new_String(ctx, B(bufn), NULL));
 	KNH_INITv(TC->cstruct, new_ClassStruct0(ctx, 0, 8));
 	KNH_INITv(TC->cmap, ctx->share->ClassTable[CLASS_Any].cmap);
-	konoha_seClassTableDefaultValue(ctx, cid, KNH_NULL, NULL);
+	konoha_setClassDefaultValue(ctx, cid, KNH_NULL, NULL);
 	knh_NameSpace_setLocalName(ctx, ns, cid);
 
 	if(SP(StmtCLASS_interface(stmt))->stt != STT_DONE) {
@@ -204,7 +204,7 @@ int knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		int i, n = DP(istmt)->size;
 		for(i = 0; i < n; i++) {
 			Token *tk = DP(stmt)->tokens[i];
-			knh_class_t icid = knh_NameSpace_geClassTable(ctx, ns, knh_Token_tobytes(ctx, tk));
+			knh_class_t icid = knh_NameSpace_getcid(ctx, ns, knh_Token_tobytes(ctx, tk));
 			if(icid == CLASS_unknown) {
 				knh_Token_perror(ctx, tk, KMSG_UCLASSN);
 				continue;
@@ -280,14 +280,14 @@ int knh_StmtUIMPORT_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	Token *tk = DP(stmt)->tokens[0];
 	knh_bytes_t name = knh_Token_tobytes(ctx, tk);
 	knh_index_t loc = knh_bytes_rindex(name, '.');
-	if(loc != -1) { /* using Math.sin */
+	if(loc != -1) { /* using math.Math */
 		if(knh_System_loadPackage(ctx, knh_bytes_first(name, loc))) {
-			knh_class_t newcid = knh_NameSpace_geClassTable(ctx, knh_rootNameSpace, name);
+			knh_class_t newcid = konoha_getcid(ctx, name);
 			if(newcid == CLASS_unknown) {
 				knh_Token_perror(ctx, tk, KMSG_UCLASSN);
 				return 0;
 			}
-			knh_class_t oldcid = knh_NameSpace_geClassTable(ctx, ns, knh_bytes_last(name, loc+1));
+			knh_class_t oldcid = knh_NameSpace_getcid(ctx, ns, knh_bytes_last(name, loc+1));
 			if(oldcid != CLASS_unknown && newcid != oldcid) {
 				KNH_WARNING(ctx, "ovrriding.. %s => %s", CLASSN(oldcid), CLASSN(newcid));
 			}
@@ -297,7 +297,7 @@ int knh_StmtUIMPORT_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	}else {
 		if(knh_System_loadPackage(ctx, name)) {
 			if(knh_Token_isTailWildCard(tk)) {
-				knh_NameSpace_import(ctx, ns, name);
+				knh_NameSpace_importClass(ctx, ns, name);
 			}
 			return 1;
 		}
@@ -360,7 +360,7 @@ int knh_StmtXCLASS_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_class
 		cid = bcid;
 	}
 
-	knh_class_t oldcid = knh_NameSpace_geClassTable(ctx, ns, knh_Token_tobytes(ctx, tkclassn));
+	knh_class_t oldcid = knh_NameSpace_getcid(ctx, ns, knh_Token_tobytes(ctx, tkclassn));
 	if(oldcid != CLASS_unknown && cid != oldcid) {
 		KNH_WARNING(ctx, "Overriding %s", knh_Token_tobytes(ctx, tkclassn));
 	}
@@ -403,7 +403,7 @@ int knh_StmtUFUNC_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	knh_bytes_t name = knh_Token_tobytes(ctx, tk);
 	if(SP(tk)->tt == TT_CMETHODN) {
 		knh_index_t loc = knh_bytes_rindex(name, '.');
-		knh_class_t cid = knh_NameSpace_geClassTable(ctx, ns, knh_bytes_first(name, loc));
+		knh_class_t cid = knh_NameSpace_getcid(ctx, ns, knh_bytes_first(name, loc));
 		if(cid == CLASS_unknown) {
 			knh_Token_perror(ctx, tk, KMSG_UCLASSN);
 			return 0;
@@ -416,7 +416,7 @@ int knh_StmtUFUNC_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		knh_NameSpace_setFuncClass(ctx, ns, mn, cid);
 	}
 	else {
-		knh_class_t cid = knh_NameSpace_geClassTable(ctx, ns, name);
+		knh_class_t cid = knh_NameSpace_getcid(ctx, ns, name);
 		if(cid == CLASS_unknown) {
 			knh_Token_perror(ctx, tk, KMSG_UCLASSN);
 			return 0;
@@ -630,6 +630,15 @@ int knh_Stmt_complie(Ctx *ctx, Stmt *stmt, String *nsname, int isEval)
 		cur = DP(cur)->next;
 	}
 
+	if(DP(abr)->dlhdr != NULL) {
+		DBG2_P("init function");
+		knh_finit finit = (knh_finit)knh_dlsym(ctx, DP(abr)->dlhdr, "init");
+		if(finit != NULL) {
+			finit(ctx);
+		}
+		DP(abr)->dlhdr = NULL;
+	}
+
 	cur = stmt;
 	while(IS_Stmt(cur)) {
 		knh_stmt_t stt = SP(cur)->stt;
@@ -720,7 +729,6 @@ void knh_Asm_openlib(Ctx *ctx, Asm *abr, knh_bytes_t fpath)
 	knh_Bytes_putc(ctx, cwb.ba, 0);
 
 	if(DP(abr)->dlhdr != NULL) {
-		//knh_dlclose(ctx, DP(abr)->dlhdr);
 		DP(abr)->dlhdr = NULL;
 	}
 
@@ -728,10 +736,6 @@ void knh_Asm_openlib(Ctx *ctx, Asm *abr, knh_bytes_t fpath)
 	DP(abr)->dlhdr =knh_dlopen(ctx, (char*)f.buf, KNH_RTLD_LAZY);
 	if(DP(abr)->dlhdr != NULL) {
 		KNH_NOTICE(ctx, "opened dynamic library: %s", f.buf);
-		knh_finit finit = (knh_finit)knh_dlsym(ctx, DP(abr)->dlhdr, "init");
-		if(finit != NULL) {
-			finit(ctx);
-		}
 	}
 	else {
 		if(knh_isfile(ctx, f)) {
