@@ -2836,9 +2836,9 @@ static Stmt *new_StmtTHROW(Ctx *ctx, knh_tokens_t *tc)
 /* ------------------------------------------------------------------------ */
 /* [local] */
 
-static Stmt *new_StmtLOCAL(Ctx *ctx, knh_tokens_t *tc)
+static Stmt *new_StmtREGISTER(Ctx *ctx, knh_tokens_t *tc)
 {
-	Stmt *o = new_StmtMETA(ctx, tc, STT_LOCAL);
+	Stmt *o = new_StmtMETA(ctx, tc, STT_REGISTER);
 	knh_Stmt_add_EXPRs(ctx, o, tc); /* expr* */
 	//knh_Stmt_add_SEMICOLON(ctx, o, tc); /* ; */
 	return o;
@@ -3046,15 +3046,21 @@ static Stmt *new_StmtSTMT1(Ctx *ctx, knh_tokens_t *tc)
 		goto L_TAIL;
 	case TT_METAN:
 	{
-		DBG2_P("Found METAN '@%s', tc->meta=%d", sToken(tkc), tc->meta);
 		if(tc->meta == -1) tc->meta = tc->c - 1;
+		//DBG2_P("Found METAN '@%s', tc->meta=%d", sToken(tkc), tc->meta);
 		if(DP(tkc)->tt_next == TT_PARENTHESIS) {
 			tc->c += 1;
-		};
+		}
 		if(DP(tkc)->tt_next == TT_BRACE) {
 			DBG2_P("Found DATA '@%s', tc->meta=%d", sToken(tkc), tc->meta);
 			tc->c += 1;
-		};
+		}
+		if(DP(tkc)->tt_next == TT_TYPEN) {
+			DBG2_ASSERT(IS_String(DP(tc->ts[tc->c])->text));
+			if(knh_String_equals(DP(tc->ts[tc->c])->text, STEXT("Unsafe"))) {
+				knh_Token_setUnsafeType(tc->ts[tc->c], 1);
+			}
+		}
 		goto L_TAIL;
 	}
 
@@ -3121,8 +3127,8 @@ static Stmt *new_StmtSTMT1(Ctx *ctx, knh_tokens_t *tc)
 		break;  /* NOTHERE */
 	case TT_THROW:
 		return new_StmtTHROW(ctx, tc);
-	case TT_LOCAL:
-		return new_StmtLOCAL(ctx, tc);
+	case TT_REGISTER:
+		return new_StmtREGISTER(ctx, tc);
 	case TT_PRINT:
 		return new_StmtPRINT(ctx, tc);
 	case TT_ASSERT:
