@@ -148,6 +148,10 @@ Token *new_Token__NAME(Ctx *ctx, knh_flag_t flag, InputStream *in, knh_bytes_t t
 				}
 				continue; /* ignoring '_' */
 			}
+			if(t.buf[i] == '?') {
+				flag |= KNH_FLAG_TKF_NULLABLETYPE;
+				goto TOKEN_PART;
+			}
 			if(!isalnum(t.buf[i]) && t.buf[i] != ':') {
 				char cb[2] = {t.buf[i], 0};
 				knh_InputStream_perror(ctx, in, KMSG_WCHAR, cb);
@@ -244,6 +248,9 @@ Token *new_Token__NAME(Ctx *ctx, knh_flag_t flag, InputStream *in, knh_bytes_t t
 			if(name[0] == 'v' && name[1] == 'o' && name[2] == 'i' && name[3] == 'd' && name[4] == 0) {
 				tt = TT_TYPEN;
 			}
+			if(name[0] == 'v' && name[1] == 'a' && name[2] == 'r' && name[3] == 0) {
+				tt = TT_TYPEN;
+			}
 			if(name[0] == 'a' && name[1] == 'n' && name[2] == 'y' && name[3] == 0) {
 				name[0] = 'A';
 				tt = TT_TYPEN;
@@ -383,7 +390,7 @@ void knh_Token_add_space(Ctx *ctx, Token *tk, int *BOL, knh_cwb_t tbuf, InputStr
 			*BOL = 0; goto L_CLEAR;
 		}
 		if(t.buf[0] == '?' && t.buf[2] == '\0') {
-			knh_Token_setPluralType(tkp, 1);
+			knh_Token_setNullableType(tkp, 1);
 			*BOL = 0; goto L_CLEAR;
 		}
 	}
@@ -486,7 +493,6 @@ int knh_Token_toClosureType(Ctx *ctx, Token *tkt, Token *tkp)
 	if(tc.e == 0) {
 		knh_cwb_clear(cwb);
 		return 0;
-		//knh_write(ctx, cwb.w, STEXT("void"));
 	}
 	knh_putc(ctx, cwb.w, ')');
 	KNH_SETv(ctx, DP(tkt)->data, new_String__cwb(ctx, cwb));
@@ -661,7 +667,7 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 	Token *tks[TKSTACK_MAXSIZ] = {NULL};
 	Token *blocktk = NULL;
 	tks[0] = tk;
-	int tkl = 0;
+	int tkl = 0, equote = 1;
 
 	INDENT_PART:;
 	pindent = indent;
@@ -704,7 +710,9 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 		case '{': case '[': case '(':
 			knh_Token_add_space(ctx, tks[tkl], &BOL, tbuf, in);
 			if(tkl < (TKSTACK_MAXSIZ - 1)) {
-				Token *intk = new_Token(ctx, 0, DP(in)->fileid, DP(in)->line, knh_char_totoken(ch));
+				Token *intk = new_Token(ctx,
+						(equote == 2) ? KNH_FLAG_TKF_TAILWILDCARD : 0,
+								DP(in)->fileid, DP(in)->line, knh_char_totoken(ch));
 				knh_Token_padd(ctx, tks[tkl], &BOL, intk);
 				tkl++;
 				tks[tkl] = intk;
@@ -717,6 +725,7 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 				knh_InputStream_skipBLOCK(ctx, in, prev, blocktk);
 				blocktk = NULL;
 			}
+			equote= 1;
 			goto MAIN_PART;
 
 		case '}':
@@ -730,6 +739,7 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 				knh_InputStream_skipBLOCK(ctx, in, prev, blocktk);
 				blocktk = NULL;
 			}
+			equote = 0;
 			goto MAIN_PART;
 
 		case ')':
@@ -743,6 +753,7 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 				knh_InputStream_skipBLOCK(ctx, in, prev, blocktk);
 				blocktk = NULL;
 			}
+			equote = 0;
 			goto MAIN_PART;
 
 		case ']':
@@ -756,26 +767,31 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 				knh_InputStream_skipBLOCK(ctx, in, prev, blocktk);
 				blocktk = NULL;
 			}
+			equote = 0;
 			goto MAIN_PART;
 
 		case '"': case '\'': case '`' :
 			knh_Token_add_space(ctx, tks[tkl], &BOL, tbuf, in);
 			prev = ch;
+			equote = 0;
 			goto QUOTED_PART;
 
 		case ';':
 			knh_Token_add_space(ctx, tks[tkl], &BOL, tbuf, in);
 			knh_Token_padd(ctx, tks[tkl], &BOL, new_Token(ctx, 0, DP(in)->fileid, DP(in)->line, knh_char_totoken(ch)));
+			equote = 1;
 			break;
 
 		case ',':
 			knh_Token_add_space(ctx, tks[tkl], &BOL, tbuf, in);
 			knh_Token_padd(ctx, tks[tkl], &BOL, new_Token(ctx, 0, DP(in)->fileid, DP(in)->line, knh_char_totoken(ch)));
+			equote = 1;
 			break;
 
 		case '$':
 			knh_Token_add_space(ctx, tks[tkl], &BOL, tbuf, in);
 			prev = ch;
+			equote = 0;
 			goto QNAME_PART;
 
 		case '@':
@@ -783,10 +799,12 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 			ch = knh_InputStream_getc(ctx, in);
 			if(ch == '"' || ch == '\'' || ch == '`') {
 				prev = ch;
+				equote = 0;
 				goto RAWSTR_PART;
 			}
 			prev = '@';
 			knh_Bytes_putc(ctx, tbuf.ba, ch);
+			equote = 1;
 			goto QNAME_PART;
 
 		case '%':
@@ -809,15 +827,37 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 				goto MAIN_PART_INLOOP;
 			}
 
+		case '|':
+			knh_Token_add_space(ctx, tks[tkl], &BOL, tbuf, in);
+			if(tkl > 0 && SP(tks[tkl])->tt == TT_PARENTHESIS
+					&& knh_Token_isTailWildCard(tks[tkl])) {
+				knh_Token_join(ctx, tks[tkl]);
+				tkl--;
+				knh_Bytes_write(ctx, tbuf.ba, STEXT(".size"));
+				knh_Token_add_space(ctx, tks[tkl], &BOL, tbuf, in);
+				equote = 0;
+				goto MAIN_PART;
+			}
+
+			DBG2_P("IS EXTENDED QUOTE: %s", (equote) ? "yes" : "no");
+
+			if(equote == 1) {
+				equote = 2; /*very dirty orz */
+				ch = '(';
+				goto MAIN_PART_INLOOP;
+			}
+
 		case '+': case '-': case '*': case '=':
-		case '&': case '|': case '<':
+		case '&': case '<':
 		case '>': case '^': case '!': case '~':
 			knh_Token_add_space(ctx, tks[tkl], &BOL, tbuf, in);
 			knh_Bytes_putc(ctx, tbuf.ba, ch);
 			prev = ch;
+			equote = 1;
 			goto OP_PART;
 
 		case '?':
+			equote = 1;
 			if(!islower(prev)) {
 				knh_Token_add_space(ctx, tks[tkl], &BOL, tbuf, in);
 				knh_Bytes_putc(ctx, tbuf.ba, ch);
@@ -838,15 +878,26 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 			}else if(ch == '/') {
 				goto LINE_COMMENT;
 			}
-			knh_Bytes_putc(ctx, tbuf.ba, '/');
+			DBG2_P("IS EXTENDED QUOTE: %s", (equote) ? "yes" : "no");
 			prev = '/';
-			goto OP_PART_INLOOP;
+			if(equote == 0 || ch == ' ' || ch == '\t') {
+				knh_Bytes_putc(ctx, tbuf.ba, '/');
+				equote = 1;
+				goto OP_PART_INLOOP;
+			}
+			else {
+				equote = 0;
+				knh_Bytes_write(ctx, tbuf.ba, STEXT("re:"));
+				knh_Bytes_putc(ctx, tbuf.ba, ch);
+				goto RESTR_PART;
+			}
 
 		case '#':
 			knh_Token_add_space(ctx, tks[tkl], &BOL, tbuf, in);
 			goto LINE_COMMENT;
 
 		case '.':
+			equote = 0;
 			ch = knh_InputStream_getc(ctx, in);
 			if(ch == '.') { /* .. */
 				knh_Token_add_space(ctx, tks[tkl], &BOL, tbuf, in);
@@ -870,8 +921,10 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 
 		case ':':
 			ch = knh_InputStream_getc(ctx, in);
+			equote = 1;
 			if(knh_cwb_size(tbuf) == 0) {
 				if(ch == ' ' || ch == '\n' || ch == '\t' || ch == '\r' || ch == ';') {
+					equote = 1;
 					knh_Bytes_putc(ctx, tbuf.ba, ':');
 					knh_Token_add_space(ctx, tks[tkl], &BOL, tbuf, in);
 					break;
@@ -886,7 +939,6 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 			}
 			else if(ch == ' ' || ch == '\n' || ch == '\t' || ch == '\r' || ch == ';') {
 				knh_Token_padd(ctx, tks[tkl], &BOL, new_Token__buffer(ctx, TT_LABEL, tbuf, in));
-				//knh_Bytes_putc(ctx, tbuf.ba, ':');
 				goto MAIN_PART_INLOOP;
 			}
 			else {
@@ -897,6 +949,7 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 
 		case '1': case '2': case '3': case '4': case '5':
 		case '6': case '7': case '8': case '9': case '0':
+			equote = 0;
 			if(knh_cwb_size(tbuf) == 0) {
 				knh_Bytes_putc(ctx, tbuf.ba, ch);
 				goto NUM_PART;
@@ -909,6 +962,7 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 			break;
 
 		default:
+			equote = 0;
 			if(ch > 127) {
 				knh_InputStream_perror(ctx, in, KMSG_WASCII, NULL);
 				ch = ' ';
@@ -930,7 +984,9 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 				case '5': case '6': case '7': case '8': case '9':
 				case '_':
 					knh_Bytes_putc(ctx, tbuf.ba, ch);
+					prev = ch;
 				break;
+
 				case '.':
 					ch = knh_InputStream_getc(ctx, in);
 					if(ch == '.') {
@@ -940,6 +996,7 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 					}
 					else {
 						knh_Bytes_putc(ctx, tbuf.ba, '.');
+						prev = ch;
 						goto NUM_PART_INLOOP;
 					}
 				break;
@@ -956,6 +1013,7 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 						goto MAIN_PART_INLOOP;
 					}
 					else if(unit == 0) {
+						prev = ch;
 						knh_Bytes_putc(ctx, tbuf.ba, ch);
 						knh_Token_padd(ctx, tks[tkl], &BOL, new_Token__buffer(ctx, TT_NUM, tbuf, in));
 						goto MAIN_PART;
@@ -964,9 +1022,15 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 
 				default:
 					if(unit > 0 || isalnum(ch) || ch > 127) {  /* 1.0a */
+						prev = ch;
 						knh_Bytes_putc(ctx, tbuf.ba, ch);
 					}
 					else {
+						if(ch == '-' && (prev == 'e' || prev == 'E')) {
+							prev = ch;
+							knh_Bytes_putc(ctx, tbuf.ba, ch);
+							break;
+						}
 						knh_Token_padd(ctx, tks[tkl], &BOL, new_Token__buffer(ctx, TT_NUM, tbuf, in));
 						goto MAIN_PART_INLOOP;
 					}
@@ -1042,8 +1106,43 @@ void knh_Token_parse(Ctx *ctx, Token *tk, InputStream *in)
 	}/*URN_PART*/
 	goto L_EOF;
 
+	RESTR_PART:;
+	DBG2_ASSERT(prev == '/');
+	{
+		while((ch = knh_InputStream_getc(ctx, in)) != EOF) {
+			RESTR_PART_INLOOP:;
+			if(ch == '\\') {
+				ch = knh_InputStream_getc(ctx, in);
+				if(ch == '/') {
+					knh_Bytes_putc(ctx, tbuf.ba, '/');
+				}
+				else if(ch == '\\') {
+					knh_Bytes_putc(ctx, tbuf.ba, ch);
+					knh_Bytes_putc(ctx, tbuf.ba, ch);
+				}
+				else {
+					knh_Bytes_putc(ctx, tbuf.ba, '\\');
+					goto RESTR_PART_INLOOP;
+				}
+				continue;
+			}
+			if(ch == '\n' || ch == '\r' || ch == EOF) {
+				knh_InputStream_perror(ctx, in, KMSG_WCHAR, "\\n");
+				knh_Token_padd(ctx, tks[tkl], &BOL, new_Token__buffer(ctx, knh_char_totoken(prev), tbuf, in));
+				goto MAIN_PART_INLOOP;
+			}
+			if(ch == prev) {
+				knh_Token_padd(ctx, tks[tkl], &BOL, new_Token__buffer(ctx, TT_TSTR, tbuf, in));
+				goto MAIN_PART;
+			}
+			knh_Bytes_putc(ctx, tbuf.ba, ch);
+		}
+		knh_Token_padd(ctx, tks[tkl], &BOL, new_Token__buffer(ctx, TT_TSTR, tbuf, in));
+	}/*RAWSTR_PART*/
+	goto L_EOF;
+
 	RAWSTR_PART:;
-	KNH_ASSERT(prev == '"' || prev == '\'' || prev == '`');
+	DBG2_ASSERT(prev == '"' || prev == '\'' || prev == '`');
 	{
 		//knh_Bytes_putc(ctx, tbuf.ba, prev);
 		while((ch = knh_InputStream_getc(ctx, in)) != EOF) {
