@@ -158,16 +158,19 @@ void knh_ClassStruct_initField(Ctx *ctx, ClassStruct *cs, knh_class_t self_cid,
 	for(i = 0; i < cs->fsize; i++) {
 #ifdef KNH_USING_UNBOXFIELD
 		if(cf[i].type == NNTYPE_Int) {
-			knh_int_t *data = (knh_int_t*)v[i];
-			data[0] = 0; continue;
+			knh_int_t *data = (knh_int_t*)(v + i);
+			data[0] = IS_NULL(cf[i].value) ? 0 : ((Int*)cf[i].value)->n.ivalue;
+			continue;
 		}
 		if(cf[i].type == NNTYPE_Float) {
-			knh_float_t *data = (knh_float_t*)v[i];
-			data[0] = 0.0; continue;
+			knh_float_t *data = (knh_float_t*)(v + i);
+			data[0] = IS_NULL(cf[i].value) ? 0.0 : ((Int*)cf[i].value)->n.fvalue;
+			continue;
 		}
 		if(cf[i].type == NNTYPE_Boolean) {
-			knh_bool_t *data = (knh_bool_t*)v[i];
-			data[0] = 0; continue;
+			knh_bool_t *data = (knh_bool_t*)(v + i);
+			data[0] = IS_NULL(cf[i].value) ? 0 : ((Int*)cf[i].value)->n.bvalue;
+			continue;
 		}
 		if(cf[i].type == CLASS_unknown) {
 			continue;
@@ -212,7 +215,6 @@ void knh_ObjectField_init(Ctx *ctx, knh_ObjectField_t *of, int init)
 static
 void knh_ObjectField_traverse(Ctx *ctx, knh_ObjectField_t *of, knh_ftraverse ftr)
 {
-#ifdef KNH_USING_UNBOXFIELD
 	knh_class_t cid = knh_Object_cid(of);
 	while(cid != CLASS_Object) {
 		knh_ClassStruct_t *cs = ctx->share->ClassTable[cid].cstruct;
@@ -224,16 +226,11 @@ void knh_ObjectField_traverse(Ctx *ctx, knh_ObjectField_t *of, knh_ftraverse ftr
 			if(cs->fields[i].type == CLASS_unknown) {
 				continue;
 			}
+			if(of->fields[i + offset] == NULL) return; /* for Script */
 			ftr(ctx, of->fields[i + offset]);
 		}
 		cid = ctx->share->ClassTable[cid].supcid;
 	}
-#else/*KNH_USING_UNBOXFIELD*/
-	size_t i;
-	for(i = 0; i < of->bsize; i++) {
-		ftr(ctx, of->fields[i]);
-	}
-#endif/*KNH_USING_UNBOXFIELD*/
 }
 
 /* ======================================================================== */
@@ -1110,7 +1107,7 @@ void knh_ClassStruct_init(Ctx *ctx, ClassStruct *b, int init)
 		knh_intptr_t i;
 		for(i = 0; i < b->fsize; i++) {
 			b->fields[i].flag = 0;
-			b->fields[i].type = TYPE_any;
+			b->fields[i].type = TYPE_Any;
 			b->fields[i].fn   = FIELDN_NONAME;
 			KNH_INITv(b->fields[i].value, KNH_NULL);
 		}
@@ -1121,18 +1118,18 @@ void knh_ClassStruct_init(Ctx *ctx, ClassStruct *b, int init)
 /* ------------------------------------------------------------------------ */
 
 static
-void knh_ClassStruct_traverse(Ctx *ctx, ClassStruct *b, knh_ftraverse gc)
+void knh_ClassStruct_traverse(Ctx *ctx, ClassStruct *b, knh_ftraverse ftr)
 {
 	if(b->fields != NULL) {
 		knh_intptr_t i;
 		for(i = 0; i < b->fsize; i++) {
-			gc(ctx, b->fields[i].value);
+			ftr(ctx, b->fields[i].value);
 		}
-		if(IS_SWEEP(gc)) {
+		if(IS_SWEEP(ftr)) {
 			KNH_FREE(ctx, b->fields, b->fsize * sizeof(knh_cfield_t));
 		}
 	}
-	gc(ctx, UP(b->methods));
+	ftr(ctx, UP(b->methods));
 }
 
 /* ======================================================================== */
@@ -1959,7 +1956,7 @@ knh_ExceptionHandler_traverse(Ctx *ctx, ExceptionHandler *hdr, knh_ftraverse gc)
 
 #define knh_Script_init_ NULL
 #define knh_Script_copy NULL
-#define knh_Script_traverse_ NULL
+#define knh_Script_traverse knh_ObjectField_traverse
 #define knh_Script_compareTo NULL
 #define knh_Script_hashCode NULL
 #define knh_Script_newClass NULL
@@ -1968,26 +1965,8 @@ knh_ExceptionHandler_traverse(Ctx *ctx, ExceptionHandler *hdr, knh_ftraverse gc)
 static
 void knh_Script_init(Ctx *ctx, Script *s, int init)
 {
-	int i;
 	s->fields = (Object**)KNH_MALLOC(ctx, sizeof(Object*) * KNH_SCRIPT_FIELDSIZE);
-	for(i = 0; i < KNH_SCRIPT_FIELDSIZE; i++) {
-		KNH_INITv(s->fields[i], KNH_NULL);
-	}
-}
-
-/* ------------------------------------------------------------------------ */
-
-static
-void knh_Script_traverse(Ctx *ctx, Script *s, knh_ftraverse ftr)
-{
-	int i;
-	for(i = 0; i < KNH_SCRIPT_FIELDSIZE; i++) {
-		ftr(ctx, s->fields[i]);
-	}
-//	automatically free
-//	if(IS_SWEEP(ftr)) {
-//		KNH_FREE(ctx, s->fields, sizeof(Object*) * KNH_SCRIPT_FIELDSIZE);
-//	}
+	knh_bzero(s->fields, sizeof(Object*) * KNH_SCRIPT_FIELDSIZE);
 }
 
 /* ======================================================================== */
@@ -2007,12 +1986,11 @@ void knh_NameSpace_init(Ctx *ctx, NameSpace *ns, int init)
 {
 	knh_NameSpace_struct *b = DP(ns);
 	if(init != KNH_OBJECT_RAWINIT) { /* @see(new_NameSpace) */
-		KNH_INITv(b->parent, KNH_NULL);
 		KNH_INITv(b->nsname, KNH_NULL);
-		KNH_INITv(b->name2cidDictSet, KNH_NULL);
 	}
+	KNH_INITv(b->name2cidDictSet, new_DictSet(ctx, 64));
 	KNH_INITv(b->script, KNH_NULL);
-	KNH_INITv(b->imports, KNH_NULL);
+	KNH_INITv(b->importedNameSpaces, KNH_NULL);
 	KNH_INITv(b->lconstDictMap, KNH_NULL);
 	KNH_INITv(b->tag2urnDictMap, KNH_NULL);
 	KNH_INITv(b->func2cidDictSet, KNH_NULL);
@@ -2024,23 +2002,13 @@ static
 void knh_NameSpace_traverse(Ctx *ctx, NameSpace *ns, knh_ftraverse ftr)
 {
 	knh_NameSpace_struct *b = DP(ns);
-	ftr(ctx, UP(b->parent));
 	ftr(ctx, UP(b->nsname));
 	ftr(ctx, UP(b->script));
-	ftr(ctx, UP(b->imports));
+	ftr(ctx, UP(b->importedNameSpaces));
 	ftr(ctx, UP(b->lconstDictMap));
 	ftr(ctx, UP(b->name2cidDictSet));
 	ftr(ctx, UP(b->tag2urnDictMap));
 	ftr(ctx, UP(b->func2cidDictSet));
-//	if(b->pkgmeta != NULL && b->pkgmeta->ftraverse != NULL) {
-//		b->pkgmeta->ftraverse(ctx, ftr);
-//	}
-//	if(IS_SWEEP(ftr)) {
-//		if(b->dlhdr != NULL) {
-//			knh_dlclose(ctx, b->dlhdr);
-//			b->dlhdr = NULL;
-//		}
-//	}
 }
 
 /* ------------------------------------------------------------------------ */
@@ -2075,8 +2043,8 @@ void knh_System_init(Ctx *ctx, System *o, int init)
 	sys->sysid = knh_autoSystemId++;
 	sys->ctxcount = 0;
 
-	KNH_INITv(sys->ns, new_NameSpace(ctx, (NameSpace*)KNH_NULL, TS_EMPTY));
-	KNH_INITv(sys->ExptNameDictSet, new_DictSet(ctx, KNH_TEXPT_SIZE));
+	KNH_INITv(sys->ClassNameDictSet, new_DictSet(ctx, KNH_TCLASS_SIZE/2));
+	KNH_INITv(sys->ExptNameDictSet, new_DictSet(ctx, KNH_TEXPT_SIZE/2));
 
 	KNH_INITv(sys->enc,   new_String__T(ctx, konoha_encoding()));
 	KNH_INITv(sys->in,    new_InputStream__stdio(ctx, stdin, sys->enc));
@@ -2085,8 +2053,6 @@ void knh_System_init(Ctx *ctx, System *o, int init)
 
 	KNH_INITv(sys->props, new_DictMap0(ctx, 64));
 
-	KNH_INITv(sys->GlobalConstDictMap, new_DictMap0(ctx, 256));
-
 	KNH_INITv(sys->FieldNameDictIdx, new_DictIdx0__ignoreCase(ctx, KNH_TFIELDN_SIZE * 2, 0));
 	KNH_INITv(sys->FileNameDictIdx, new_DictIdx0(ctx, 32, 0));
 	knh_DictIdx_add__fast(ctx, sys->FileNameDictIdx, new_String__T(ctx, "(unknown)"));
@@ -2117,15 +2083,14 @@ static void knh_System_traverse(Ctx *ctx, System *o, knh_ftraverse ftr)
 {
 	knh_System_struct *sys = DP(o);
 
-	ftr(ctx, UP(sys->ns));
 	ftr(ctx, UP(sys->enc));
 	ftr(ctx, UP(sys->in));
 	ftr(ctx, UP(sys->out));
 	ftr(ctx, UP(sys->err));
 
 	ftr(ctx, UP(sys->props));
-	ftr(ctx, UP(sys->GlobalConstDictMap));
 	ftr(ctx, UP(sys->ExptNameDictSet));
+	ftr(ctx, UP(sys->ClassNameDictSet));
 
 	ftr(ctx, UP(sys->FieldNameDictIdx));
 	ftr(ctx, UP(sys->FileNameDictIdx));
@@ -2296,11 +2261,12 @@ void knh_Asm_init(Ctx *ctx, Asm *abr, int init)
 //		b->vars[i].count = 0;
 		KNH_INITv(b->vars[i].value, KNH_NULL);
 	}
-
-	KNH_INITv(b->registeredStmts, new_Array0(ctx, 8));
 	b->stack = 0;
 	b->globalidx = -1;
 
+	b->regs = (knh_asmreg_t*)KNH_MALLOC(ctx, KNH_ASM_REGMAX * sizeof(knh_asmreg_t));
+	b->regs_size = 0;
+
 	b->labels = NULL;
 	b->labelmax = 0;
 	b->labelcapacity = 0;
@@ -2337,13 +2303,15 @@ void knh_Asm_traverse(Ctx *ctx, Asm *abr, knh_ftraverse ftr)
 		if(b->labels != NULL) {
 			KNH_FREE(ctx, b->labels, b->labelcapacity * sizeof(knh_labeltbl_t));
 		}
+		KNH_FREE(ctx, b->regs, KNH_ASM_REGMAX * sizeof(knh_asmreg_t));
+		b->regs_size = 0;
 	}
 
 	ftr(ctx, UP(b->ns));
 	ftr(ctx, UP(b->mtd));
 	ftr(ctx, UP(b->elf));
 	ftr(ctx, UP(b->dwarf));
-	ftr(ctx, UP(b->registeredStmts));
+
 	ftr(ctx, UP(b->name2labelIdDictSet));
 	ftr(ctx, UP(b->lstacks));
 	ftr(ctx, UP(b->finallyStmt));
@@ -2552,7 +2520,7 @@ Object *knh_StringX_fdefault(Ctx *ctx, knh_class_t cid)
 static
 Object *knh_NameSpace_fdefault(Ctx *ctx, knh_class_t cid)
 {
-	return (Object*)DP(ctx->sys)->ns;
+	return UP(ctx->ns);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -2718,7 +2686,7 @@ void konoha_loadClassData(Ctx *ctx, knh_ClassData_t *data)
 			ctx->share->ClassTableSize = cid;
 		}
 
-		konoha_seClassTableName(ctx, cid, new_String__T(ctx, data->name));
+		konoha_setClassName(ctx, cid, new_String__T(ctx, data->name));
 
 		ctx->share->ClassTable[cid].cflag  = data->flag;
 		ctx->share->ClassTable[cid].oflag  = KNH_FLAG_CF2OF(data->flag);
@@ -2760,7 +2728,7 @@ void konoha_loadClassData(Ctx *ctx, knh_ClassData_t *data)
 			cm = new_ClassMap0(ctx, data->mapper_size);
 		}
 		KNH_INITv(ctx->share->ClassTable[cid].cmap, cm);
-		konoha_seClassTableDefaultValue(ctx, cid, KNH_NULL, data->fdefault);
+		konoha_setClassDefaultValue(ctx, cid, KNH_NULL, data->fdefault);
 		data++;
 	}
 }
@@ -2948,12 +2916,12 @@ static void konoha_loadClassProperties(Ctx *ctx)
 	KNH_SETv(ctx, ctx->share->ClassTable[CLASS_String].cspec,
 			new_StringUnit(ctx, 0, CLASS_String, TS_EMPTY));
 
-	konoha_seClassTableParam(ctx, CLASS_Array, CLASS_Any, CLASS_Nue);
-	konoha_seClassTableParam(ctx, CLASS_Iterator, CLASS_Any, CLASS_Nue);
-	konoha_seClassTableParam(ctx, CLASS_DictMap, CLASS_Any, CLASS_Nue);
-	konoha_seClassTableParam(ctx, CLASS_DictSet, CLASS_Any, CLASS_Nue);
-	konoha_seClassTableParam(ctx, CLASS_HashMap, CLASS_Any, CLASS_Any);
-	konoha_seClassTableParam(ctx, CLASS_HashSet, CLASS_Any, CLASS_Any);
+	konoha_setClassParam(ctx, CLASS_Array, CLASS_Any, CLASS_Nue);
+	konoha_setClassParam(ctx, CLASS_Iterator, CLASS_Any, CLASS_Nue);
+	konoha_setClassParam(ctx, CLASS_DictMap, CLASS_Any, CLASS_Nue);
+	konoha_setClassParam(ctx, CLASS_DictSet, CLASS_Any, CLASS_Nue);
+	konoha_setClassParam(ctx, CLASS_HashMap, CLASS_Any, CLASS_Any);
+	konoha_setClassParam(ctx, CLASS_HashSet, CLASS_Any, CLASS_Any);
 	ctx->share->ClassTable[CLASS_Closure].r0 = CLASS_Any;
 	ctx->share->ClassTable[CLASS_Closure].p1 = CLASS_Any;
 	ctx->share->ClassTable[CLASS_Closure].p2 = CLASS_Any;
